@@ -125,6 +125,7 @@ CMainWindow::CMainWindow()
     connect(actionCreateRoutinoDatabase, &QAction::triggered,            this,      &CMainWindow::slotCreateRoutinoDatabase);
     connect(actionPrintMap,              &QAction::triggered,            this,      &CMainWindow::slotPrintMap);
     connect(actionSetupWaypointIcons,    &QAction::triggered,            this,      &CMainWindow::slotSetupWptIcons);
+    connect(actionCloseTab,              &QAction::triggered,            this,      &CMainWindow::slotCloseTab);
     connect(tabWidget,                   &QTabWidget::tabCloseRequested, this,      &CMainWindow::slotTabCloseRequest);
 
     connect(tabWidget,                   &QTabWidget::currentChanged,    this,      &CMainWindow::slotCurrentTabCanvas);
@@ -158,12 +159,15 @@ CMainWindow::CMainWindow()
     cfg.endGroup(); // Views
     testForNoView();
 
-    actionShowScale->setChecked      (cfg.value("isScaleVisible",   true).toBool());
-    actionShowGrid->setChecked       (cfg.value("isGridVisible",   false).toBool());
-    actionPOIText->setChecked        (cfg.value("POIText",          true).toBool());
-    actionMapToolTip->setChecked     (cfg.value("MapToolTip",       true).toBool());
-    actionNightDay->setChecked       (cfg.value("isNight",         false).toBool());
-    actionFlipMouseWheel->setChecked (cfg.value("flipMouseWheel",  false).toBool());
+    CCanvas::gisLayerOpacity = cfg.value("gisLayerOpacity",1.0).toFloat();
+    gisWidget->setOpacity(CCanvas::gisLayerOpacity);
+
+    actionShowScale->setChecked(cfg.value("isScaleVisible", true).toBool());
+    actionShowGrid->setChecked(cfg.value("isGridVisible", false).toBool());
+    actionPOIText->setChecked(cfg.value("POIText", true).toBool());
+    actionMapToolTip->setChecked(cfg.value("MapToolTip", true).toBool());
+    actionNightDay->setChecked(cfg.value("isNight", false).toBool());
+    actionFlipMouseWheel->setChecked(cfg.value("flipMouseWheel", false).toBool());
     actionProfileIsWindow->setChecked(cfg.value("profileIsWindow", false).toBool());
     mapFont = cfg.value("mapFont", font()).value<QFont>();
     tabWidget->setCurrentIndex(cfg.value("visibleCanvas",0).toInt());
@@ -255,6 +259,7 @@ CMainWindow::~CMainWindow()
     }
     cfg.endGroup(); // Views
 
+    cfg.setValue("gisLayerOpacity", CCanvas::gisLayerOpacity);
     cfg.setValue("visibleCanvas", tabWidget->currentIndex());
     cfg.setValue("isScaleVisible", actionShowScale->isChecked());
     cfg.setValue("isGridVisible", actionShowGrid->isChecked());
@@ -959,6 +964,20 @@ void CMainWindow::slotSetupWptIcons()
     dlg.exec();
 }
 
+
+void CMainWindow::slotCloseTab()
+{
+    CCanvas * canvas = dynamic_cast<CCanvas*>(tabWidget->currentWidget());
+    if(canvas == nullptr)
+    {
+        QWidget * widget = tabWidget->currentWidget();
+        if(widget != nullptr)
+        {
+            widget->deleteLater();
+        }
+    }
+}
+
 #ifdef WIN32
 
 static void sendDeviceEvent(DWORD unitmask, bool add)
@@ -1059,7 +1078,7 @@ void CMainWindow::slotSanityTest()
     if(pjsrc == nullptr)
     {
         QMessageBox::critical(this, tr("Fatal...")
-                              ,tr("QMapShack detected a badly installed Proj4 library. The translation tables for EPSG projections usually stored in /usr/share/proj are missing. Please contact the package maintainer of your ditribution to fix it.")
+                              ,tr("QMapShack detected a badly installed Proj4 library. The translation tables for EPSG projections usually stored in /usr/share/proj are missing. Please contact the package maintainer of your distribution to fix it.")
                               ,QMessageBox::Close);
 
         deleteLater();
@@ -1071,3 +1090,4 @@ void CMainWindow::slotSanityTest()
 
     qDebug() << "Sanity test passed.";
 }
+
