@@ -46,6 +46,7 @@
 
 #include <QtWidgets>
 
+qreal CCanvas::gisLayerOpacity = 1.0;
 
 CCanvas::CCanvas(QWidget *parent, const QString &name)
     : QWidget(parent)
@@ -344,7 +345,9 @@ void CCanvas::paintEvent(QPaintEvent*)
 
     map->draw(p, needsRedraw, posFocus);
     dem->draw(p, needsRedraw, posFocus);
+    p.setOpacity(gisLayerOpacity);
     gis->draw(p, needsRedraw, posFocus);
+    p.setOpacity(1.0);
 
     // restore coordinate system to default
     p.resetTransform();
@@ -408,6 +411,18 @@ void CCanvas::wheelEvent(QWheelEvent * e)
 {
     mouse->wheelEvent(e);
 
+    // angleDelta() returns the eighths of a degree
+    // of the mousewheel
+    // -> zoom in/out every 15 degress = every 120 eights
+    const int EIGHTS_ZOOM = 15 * 8;
+    zoomAngleDelta += e->angleDelta().y();
+    if(abs(zoomAngleDelta) < EIGHTS_ZOOM)
+    {
+        return;
+    }
+
+    zoomAngleDelta = 0;
+
     QPointF pos = e->posF();
     QPointF pt1 = pos;
 
@@ -514,7 +529,7 @@ void CCanvas::drawStatusMessages(QPainter& p)
         r.moveTopLeft(QPoint(15,45));
         p.setPen(CDraw::penBorderGray);
         p.setBrush(CDraw::brushBackWhite);
-        p.drawRoundedRect(r, 5, 5);
+        p.drawRoundedRect(r, RECT_RADIUS, RECT_RADIUS);
     }
 }
 
