@@ -148,7 +148,7 @@ void CDemDraw::buildMapList()
 
             CDemItem * item = new CDemItem(*demList, this);
 
-            item->setText(0,fi.baseName().replace("_", " "));
+            item->setText(0,fi.completeBaseName().replace("_", " "));
             item->filename = dir.absoluteFilePath(filename);
             item->updateIcon();
 
@@ -292,7 +292,8 @@ void CDemDraw::getElevationAt(const QPolygonF& pos, QPolygonF& ele)
 
     for(int i = 0; i < pos.size(); i++)
     {
-        ele[i].ry() = getElevationAt(pos[i]) * basefactor;
+        qreal tmp = getElevationAt(pos[i]);
+        ele[i].ry() = (tmp == NOFLOAT) ? NOFLOAT : tmp * basefactor;
     }
 }
 
