@@ -16,12 +16,15 @@
 
 **********************************************************************************************/
 
+#include "CMainWindow.h"
+#include "dem/CDemDraw.h"
 #include "dem/CDemItem.h"
 #include "dem/CDemList.h"
+#include "units/IUnit.h"
 
 #include <QtWidgets>
 
-void CDemTreeWidget::dragMoveEvent ( QDragMoveEvent  * event )
+void CDemTreeWidget::dragMoveEvent( QDragMoveEvent  * event )
 {
     CDemItem * item = dynamic_cast<CDemItem*>(itemAt(event->pos()));
 
@@ -36,7 +39,7 @@ void CDemTreeWidget::dragMoveEvent ( QDragMoveEvent  * event )
     }
 }
 
-void CDemTreeWidget::dropEvent ( QDropEvent  * event )
+void CDemTreeWidget::dropEvent( QDropEvent  * event )
 {
     CDemItem * item = dynamic_cast<CDemItem*>(currentItem());
     if(item)
@@ -60,13 +63,21 @@ CDemList::CDemList(QWidget *parent)
 {
     setupUi(this);
 
-    connect(treeWidget, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotContextMenu(QPoint)));
-    connect(actionActivate, SIGNAL(triggered()), this, SLOT(slotActivate()));
-
-    connect(treeWidget, SIGNAL(sigChanged()), SIGNAL(sigChanged()));
+    connect(treeWidget,     &CDemTreeWidget::customContextMenuRequested, this, &CDemList::slotContextMenu);
+    connect(actionMoveUp,   &QAction::triggered,                         this, &CDemList::slotMoveUp);
+    connect(actionMoveDown, &QAction::triggered,                         this, &CDemList::slotMoveDown);
+    connect(actionActivate, &QAction::triggered,                         this, &CDemList::slotActivate);
+    connect(actionReloadDem, &QAction::triggered,                        this, &CDemList::slotReloadDem);
+    connect(treeWidget,     &CDemTreeWidget::sigChanged,                 this, &CDemList::sigChanged);
+    connect(labelHelpFillMapList, &QLabel::linkActivated,                this, &CDemList::slotLinkActivated);
 
     menu = new QMenu(this);
     menu->addAction(actionActivate);
+    menu->addAction(actionMoveUp);
+    menu->addAction(actionMoveDown);
+    menu->addSeparator();
+    menu->addAction(actionReloadDem);
+    menu->addAction(CMainWindow::self().getDemSetupAction());
 }
 
 CDemList::~CDemList()
@@ -101,23 +112,16 @@ void CDemList::updateHelpText()
         labelHelpFillMapList->hide();
 
         CDemItem * item = dynamic_cast<CDemItem*>(treeWidget->topLevelItem(0));
-        if(item && item->isActivated())
-        {
-            labelIcon->hide();
-            labelHelpActivateMap->hide();
-        }
-        else
-        {
-            labelIcon->show();
-            labelHelpActivateMap->show();
-        }
+        bool haveActive = item && item->isActivated();
+        labelIcon->setVisible(!haveActive);
+        labelHelpActivateMap->setVisible(!haveActive);
     }
 }
 
 void CDemList::slotActivate()
 {
     CDemItem * item = dynamic_cast<CDemItem*>(treeWidget->currentItem());
-    if(item == 0)
+    if(nullptr == item)
     {
         return;
     }
@@ -131,20 +135,85 @@ void CDemList::slotActivate()
     updateHelpText();
 }
 
+void CDemList::slotMoveUp()
+{
+    CDemItem * item = dynamic_cast<CDemItem*>(treeWidget->currentItem());
+    if(item == nullptr)
+    {
+        return;
+    }
+
+    int index = treeWidget->indexOfTopLevelItem(item);
+    if(index == NOIDX)
+    {
+        return;
+    }
+
+    item->showChildren(false);
+    treeWidget->takeTopLevelItem(index);
+    treeWidget->insertTopLevelItem(index-1, item);
+    item->showChildren(true);
+    treeWidget->setCurrentItem(0);
+    emit treeWidget->sigChanged();
+}
+
+void CDemList::slotMoveDown()
+{
+    CDemItem * item = dynamic_cast<CDemItem*>(treeWidget->currentItem());
+    if(item == nullptr)
+    {
+        return;
+    }
+
+    int index = treeWidget->indexOfTopLevelItem(item);
+    if(index == NOIDX)
+    {
+        return;
+    }
+
+    item->showChildren(false);
+    treeWidget->takeTopLevelItem(index);
+    treeWidget->insertTopLevelItem(index+1, item);
+    item->showChildren(true);
+    treeWidget->setCurrentItem(0);
+    emit treeWidget->sigChanged();
+}
+
 
 void CDemList::slotContextMenu(const QPoint& point)
 {
     CDemItem * item = dynamic_cast<CDemItem*>(treeWidget->currentItem());
 
-    if(item == 0)
+    bool itemIsSelected  = nullptr != item;
+    bool itemIsActivated = item ? item->isActivated() : false;
+
+    actionActivate->setEnabled(itemIsSelected);
+    actionMoveUp->setEnabled(itemIsSelected);
+    actionMoveDown->setEnabled(itemIsSelected);
+
+    actionActivate->setChecked(itemIsActivated);
+    actionActivate->setText(itemIsActivated ? tr("Deactivate") : tr("Activate"));
+
+    if(itemIsSelected)
     {
-        return;
+        CDemItem * item1 = dynamic_cast<CDemItem*>(treeWidget->itemBelow(item));
+        actionMoveUp->setEnabled(itemIsActivated && (treeWidget->itemAbove(item) != nullptr));
+        actionMoveDown->setEnabled(itemIsActivated && item1 && item1->isActivated());
     }
-    bool activated = item->isActivated();
-    actionActivate->setChecked(activated);
-    actionActivate->setText(activated ? tr("Deactivate") : tr("Activate"));
 
     QPoint p = treeWidget->mapToGlobal(point);
     menu->exec(p);
 }
 
+void CDemList::slotReloadDem()
+{
+    CDemDraw::setupDemPath(CDemDraw::getDemPaths());
+}
+
+void CDemList::slotLinkActivated(const QString& link)
+{
+    if(link == "setup")
+    {
+        emit sigSetupDemPath();
+    }
+}
