@@ -16,19 +16,20 @@
 
 **********************************************************************************************/
 #include "CMainWindow.h"
+#include "device/CDeviceGarmin.h"
 #include "device/IDevice.h"
 #include "gis/CGisListWks.h"
 #include "gis/prj/IGisProject.h"
 #include "helpers/CSelectCopyAction.h"
 
-#ifdef Q_OS_LINUX
+#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
 #include <QtDBus>
 #endif
 
 int IDevice::cnt = 0;
 
-IDevice::IDevice(const QString &path, const QString &key, QTreeWidget *parent)
-    : QTreeWidgetItem(parent)
+IDevice::IDevice(const QString &path, type_e type, const QString &key, QTreeWidget *parent)
+    : QTreeWidgetItem(parent, type)
     , dir(path)
     , key(key)
 {
@@ -36,6 +37,14 @@ IDevice::IDevice(const QString &path, const QString &key, QTreeWidget *parent)
     cnt++;
 }
 
+IDevice::IDevice(const QString &path, type_e type, const QString &key, CDeviceGarmin *parent)
+    : QTreeWidgetItem(parent, type)
+    , dir(path)
+    , key(key)
+{
+    setIcon(CGisListWks::eColumnIcon, QIcon("://icons/32x32/PathGreen.png"));
+}
+
 IDevice::~IDevice()
 {
     cnt--;
@@ -43,18 +52,23 @@ IDevice::~IDevice()
 
 void IDevice::mount(const QString& path)
 {
-#ifdef Q_OS_LINUX
+#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
     QDBusMessage message = QDBusMessage::createMethodCall("org.freedesktop.UDisks2",path,"org.freedesktop.UDisks2.Filesystem","Mount");
     QVariantMap args;
     args.insert("options", "sync");
     message << args;
+#if defined(Q_OS_FREEBSD)
+    // XXX Hunc sint race conditions - call bsdisks (UDisks2) too fast,
+    // get a malformed reply, crash.
+    QThread::sleep(1);
+#endif
     QDBusConnection::systemBus().call(message);
 #endif
 }
 
 void IDevice::umount(const QString &path)
 {
-#ifdef Q_OS_LINUX
+#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
     QDBusMessage message = QDBusMessage::createMethodCall("org.freedesktop.UDisks2",path,"org.freedesktop.UDisks2.Filesystem","Unmount");
     QVariantMap args;
     message << args;
@@ -74,21 +88,48 @@ void IDevice::getItemsByPos(const QPointF& pos, QList<IGisItem *> &items)
     for(int n = 0; n < N; n++)
     {
         IGisProject * project = dynamic_cast<IGisProject*>(child(n));
-        if(project)
+        if(project != nullptr)
         {
             project->getItemsByPos(pos, items);
+            continue;
+        }
+
+        IDevice * device = dynamic_cast<IDevice*>(child(n));
+        if(device != nullptr)
+        {
+            device->getItemsByPos(pos, items);
+        }
+    }
+}
+
+void IDevice::getItemsByArea(const QRectF& area, IGisItem::selflags_t flags, QList<IGisItem *> &items)
+{
+    const int N = childCount();
+    for(int n = 0; n < N; n++)
+    {
+        IGisProject * project = dynamic_cast<IGisProject*>(child(n));
+        if(project != nullptr)
+        {
+            project->getItemsByArea(area, flags, items);
+            continue;
+        }
+
+        IDevice * device = dynamic_cast<IDevice*>(child(n));
+        if(device != nullptr)
+        {
+            device->getItemsByArea(area, flags, items);
         }
     }
 }
 
 IGisItem * IDevice::getItemByKey(const IGisItem::key_t& key)
 {
-    IGisItem * item = 0;
+    IGisItem * item = nullptr;
     const int N = childCount();
     for(int n = 0; n < N; n++)
     {
         IGisProject * project = dynamic_cast<IGisProject*>(child(n));
-        if(project)
+        if(project != nullptr)
         {
             if(project->getKey() != key.project)
             {
@@ -96,7 +137,17 @@ IGisItem * IDevice::getItemByKey(const IGisItem::key_t& key)
             }
 
             item = project->getItemByKey(key);
-            if(item != 0)
+            if(item != nullptr)
+            {
+                break;
+            }
+        }
+
+        IDevice * device = dynamic_cast<IDevice*>(child(n));
+        if(device != nullptr)
+        {
+            item = device->getItemByKey(key);
+            if(item != nullptr)
             {
                 break;
             }
@@ -105,13 +156,33 @@ IGisItem * IDevice::getItemByKey(const IGisItem::key_t& key)
     return item;
 }
 
+void IDevice::getItemsByKeys(const QList<IGisItem::key_t>& keys, QList<IGisItem*>& items)
+{
+    const int N = childCount();
+    for(int n = 0; n < N; n++)
+    {
+        IGisProject * project = dynamic_cast<IGisProject*>(child(n));
+        if(project != nullptr)
+        {
+            project->getItemsByKeys(keys, items);
+            continue;
+        }
+
+        IDevice * device = dynamic_cast<IDevice*>(child(n));
+        if(device != nullptr)
+        {
+            device->getItemsByKeys(keys, items);
+        }
+    }
+}
+
 IGisProject * IDevice::getProjectByKey(const QString& key)
 {
     const int N = childCount();
     for(int n = 0; n < N; n++)
     {
         IGisProject * project = dynamic_cast<IGisProject*>(child(n));
-        if(project)
+        if(project != nullptr)
         {
             if(project->getKey() != key)
             {
@@ -120,8 +191,18 @@ IGisProject * IDevice::getProjectByKey(const QString& key)
 
             return project;
         }
+
+        IDevice * device = dynamic_cast<IDevice*>(child(n));
+        if(device != nullptr)
+        {
+            project = device->getProjectByKey(key);
+            if(project != nullptr)
+            {
+                return project;
+            }
+        }
     }
-    return 0;
+    return nullptr;
 }
 
 void IDevice::editItemByKey(const IGisItem::key_t& key)
@@ -130,9 +211,16 @@ void IDevice::editItemByKey(const IGisItem::key_t& key)
     for(int n = 0; n < N; n++)
     {
         IGisProject * project = dynamic_cast<IGisProject*>(child(n));
-        if(project)
+        if(project != nullptr)
         {
             project->editItemByKey(key);
+            continue;
+        }
+
+        IDevice * device = dynamic_cast<IDevice*>(child(n));
+        if(device != nullptr)
+        {
+            device->editItemByKey(key);
         }
     }
 }
@@ -201,7 +289,7 @@ bool IDevice::testForExternalProject(const QString& filename)
 {
     if(QDir(filename).exists() || QFile::exists(filename))
     {
-        QString msg = QObject::tr("There is another project with the same name. If you press 'ok' it will be removed and replaced.");
+        QString msg = tr("There is another project with the same name. If you press 'ok' it will be removed and replaced.");
         int res = QMessageBox::warning(CMainWindow::getBestWidgetForParent(), getName(), msg, QMessageBox::Ok|QMessageBox::Abort, QMessageBox::Ok);
         if(res != QMessageBox::Ok)
         {
@@ -230,8 +318,6 @@ bool IDevice::testForExternalProject(const QString& filename)
             }
         }
     }
-
-
     return false;
 }
 
@@ -241,9 +327,16 @@ void IDevice::drawItem(QPainter& p, const QPolygonF &viewport, QList<QRectF>& bl
     for(int n = 0; n < N; n++)
     {
         IGisProject * project = dynamic_cast<IGisProject*>(child(n));
-        if(project)
+        if(project != nullptr)
         {
             project->drawItem(p, viewport, blockedAreas, gis);
+            continue;
+        }
+
+        IDevice * device = dynamic_cast<IDevice*>(child(n));
+        if(device != nullptr)
+        {
+            device->drawItem(p, viewport, blockedAreas, gis);
         }
     }
 }
@@ -254,9 +347,16 @@ void IDevice::drawLabel(QPainter& p, const QPolygonF &viewport, QList<QRectF>& b
     for(int n = 0; n < N; n++)
     {
         IGisProject * project = dynamic_cast<IGisProject*>(child(n));
-        if(project)
+        if(project != nullptr)
         {
             project->drawLabel(p, viewport, blockedAreas, fm, gis);
+            continue;
+        }
+
+        IDevice * device = dynamic_cast<IDevice*>(child(n));
+        if(device != nullptr)
+        {
+            device->drawLabel(p, viewport, blockedAreas, fm, gis);
         }
     }
 }
@@ -267,9 +367,16 @@ void IDevice::drawItem(QPainter& p, const QRectF& viewport, CGisDraw * gis)
     for(int n = 0; n < N; n++)
     {
         IGisProject * project = dynamic_cast<IGisProject*>(child(n));
-        if(project)
+        if(project != nullptr)
         {
             project->drawItem(p, viewport, gis);
+            continue;
+        }
+
+        IDevice * device = dynamic_cast<IDevice*>(child(n));
+        if(device != nullptr)
+        {
+            device->drawItem(p, viewport, gis);
         }
     }
 }
