@@ -57,6 +57,7 @@
 #include <QtSql>
 #include <QtWidgets>
 
+using std::bind;
 
 #undef  DB_VERSION
 #define DB_VERSION 3
@@ -96,12 +97,21 @@ CGisListWks::CGisListWks(QWidget *parent)
 
     menuProjectWks   = new QMenu(this);
     actionEditPrj    = menuProjectWks->addAction(QIcon("://icons/32x32/EditDetails.png"), tr("Edit.."         ), this, SLOT(slotEditPrj()));
+    actionCopyPrj    = menuProjectWks->addAction(QIcon("://icons/32x32/Copy.png"       ), tr("Copy to..."     ), this, SLOT(slotCopyProject()));
     actionShowOnMap  = menuProjectWks->addAction(QIcon("://icons/32x32/ShowAll.png"    ), tr("Show on Map"    ), this, SLOT(slotShowOnMap()));
     actionHideFrMap  = menuProjectWks->addAction(QIcon("://icons/32x32/ShowNone.png"   ), tr("Hide from Map"  ), this, SLOT(slotHideFrMap()));
 
+
+    menuProjectWks->addSeparator();
+    actionGroup = new QActionGroup(menuProjectWks);
+    actionGroup->setExclusive(true);
+    actionSortByTime = addSortAction(menuProjectWks, actionGroup, "://icons/32x32/Time.png", tr("Sort by Time"), IGisProject::eSortFolderTime);
+    actionSortByName = addSortAction(menuProjectWks, actionGroup, "://icons/32x32/SortName.png", tr("Sort by Name"), IGisProject::eSortFolderName);
+
     menuProjectWks->addSeparator();
     actionSave       = menuProjectWks->addAction(QIcon("://icons/32x32/SaveGIS.png"    ), tr("Save"           ), this, SLOT(slotSaveProject()));
-    actionSaveAs     = menuProjectWks->addAction(QIcon("://icons/32x32/SaveGISAs.png"  ), tr("Save As..."     ), this, SLOT(slotSaveAsProject()));
+    actionSaveAs     = menuProjectWks->addAction(QIcon("://icons/32x32/SaveGISAs.png"  ), tr("Save as..."     ), this, SLOT(slotSaveAsProject()));
+    actionSaveAsStrict = menuProjectWks->addAction(QIcon("://icons/32x32/SaveGISAsGpx11.png"  ), tr("Save as GPX 1.1 w/o ext..."), this, SLOT(slotSaveAsStrictGpx11Project()));
 
     menuProjectWks->addSeparator();
     actionSyncWksDev = menuProjectWks->addAction(QIcon("://icons/32x32/Device.png"     ), tr("Send to Devices"), this, SLOT(slotSyncWksDev()));
@@ -112,11 +122,10 @@ CGisListWks::CGisListWks(QWidget *parent)
 
     menuProjectDev  = new QMenu(this);
     menuProjectDev->addAction(actionEditPrj);
+    menuProjectDev->addAction(actionCopyPrj);
     menuProjectDev->addAction(actionShowOnMap);
     menuProjectDev->addAction(actionHideFrMap);
     menuProjectDev->addSeparator();
-    menuProjectDev->addAction(actionSaveAs);
-    menuProjectDev->addAction(actionSave);
     menuProjectDev->addSeparator();
     actionSyncDevWks= menuProjectDev->addAction(QIcon("://icons/32x32/Device.png"),tr("Update Project on Device"), this, SLOT(slotSyncDevWks()));
     menuProjectDev->addSeparator();
@@ -124,6 +133,7 @@ CGisListWks::CGisListWks(QWidget *parent)
 
     menuProjectTrash= new QMenu(this);
     menuProjectTrash->addAction(actionSaveAs);
+    menuProjectTrash->addAction(actionSaveAsStrict);
     menuProjectTrash->addAction(actionCloseProj);
 
     connect(this, &CGisListWks::customContextMenuRequested, this, &CGisListWks::slotContextMenu);
@@ -140,6 +150,7 @@ CGisListWks::CGisListWks(QWidget *parent)
     actionEditTrk    = menuItemTrk->addAction(QIcon("://icons/32x32/LineMove.png"),    tr("Edit Track Points"      ), this, SLOT(slotEditTrk()));
     actionReverseTrk = menuItemTrk->addAction(QIcon("://icons/32x32/Reverse.png"),     tr("Reverse Track"          ), this, SLOT(slotReverseTrk()));
     actionCombineTrk = menuItemTrk->addAction(QIcon("://icons/32x32/Combine.png"),     tr("Combine Tracks"         ), this, SLOT(slotCombineTrk()));
+    actionCopyTrkWithWpt = menuItemTrk->addAction(QIcon("://icons/32x32/CopyTrkWithWpt.png"), tr("Copy Track with Waypoints"), this, SLOT(slotCopyTrkWithWpt()));
     menuItemTrk->addSeparator();
     actionDelete    = menuItemTrk->addAction(QIcon("://icons/32x32/DeleteOne.png"),tr("Delete"), this, SLOT(slotDeleteItem()));
 
@@ -334,6 +345,19 @@ void CGisListWks::setExternalMenu(QMenu * project)
     connect(CMainWindow::self().findChild<QAction*>("actionSearchGoogle"),     &QAction::triggered, this, &CGisListWks::slotSearchGoogle);
 }
 
+QAction * CGisListWks::addSortAction(QMenu * menu, QActionGroup * actionGroup, const QString& icon, const QString& text, IGisProject::sorting_folder_e mode)
+{
+    QAction * action = menu->addAction(QIcon(icon), text);
+    action->setCheckable(true);
+
+    auto func = std::bind(&CGisListWks::slotSetSortMode, this, mode, std::placeholders::_1);
+    connect(action, &QAction::toggled, this, func);
+
+    actionGroup->addAction(action);
+
+    return action;
+}
+
 void CGisListWks::dragMoveEvent(QDragMoveEvent  * e )
 {
     CGisListWksEditLock lock(true, IGisItem::mutexItems);
@@ -940,6 +964,7 @@ void CGisListWks::slotContextMenu(const QPoint& point)
             }
             else
             {
+                actionGroup->setEnabled(false);
                 actionSyncWksDev->setEnabled(IDevice::count());
                 actionSyncDB->setEnabled(project->getType() == IGisProject::eTypeDb);
                 menuProjectWks->exec(p);
@@ -996,8 +1021,24 @@ void CGisListWks::slotContextMenu(const QPoint& point)
                 }
                 else
                 {
+                    actionGroup->setEnabled(true);
                     actionSyncWksDev->setEnabled(IDevice::count());
                     actionSyncDB->setEnabled(project->getType() == IGisProject::eTypeDb);
+
+                    blockSorting = true;
+                    switch(project->getSortingFolder())
+                    {
+                    case IGisProject::eSortFolderName:
+                        actionSortByName->setChecked(true);
+                        break;
+
+                    case IGisProject::eSortFolderTime:
+                        actionSortByTime->setChecked(true);
+                        break;
+                    }
+
+                    blockSorting = false;
+
                     menuProjectWks->exec(p);
                 }
             }
@@ -1013,6 +1054,7 @@ void CGisListWks::slotContextMenu(const QPoint& point)
             {
             case IGisItem::eTypeTrk:
             {
+                CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(gisItem);
                 IGisProject * project = gisItem->getParentProject();
                 if(project != nullptr)
                 {
@@ -1025,6 +1067,7 @@ void CGisListWks::slotContextMenu(const QPoint& point)
                 actionRangeTrk->setDisabled(isOnDevice);
                 actionReverseTrk->setDisabled(isOnDevice);
                 actionEditTrk->setDisabled(isOnDevice);
+                actionCopyTrkWithWpt->setEnabled(trk->getNumberOfAttachedWpt() != 0);
                 actionFocusTrk->setChecked(gisItem->hasUserFocus());
                 menuItemTrk->exec(p);
                 break;
@@ -1186,6 +1229,21 @@ void CGisListWks::slotSaveAsProject()
     }
 }
 
+void CGisListWks::slotSaveAsStrictGpx11Project()
+{
+    CGisListWksEditLock lock(false, IGisItem::mutexItems);
+
+    QList<QTreeWidgetItem*> items = selectedItems();
+    for(QTreeWidgetItem * item : items)
+    {
+        IGisProject * project = dynamic_cast<IGisProject*>(item);
+        if(nullptr != project)
+        {
+            project->saveAsStrictGpx11();
+        }
+    }
+}
+
 void CGisListWks::slotEditPrj()
 {
     CGisListWksEditLock lock(false, IGisItem::mutexItems);
@@ -1259,7 +1317,7 @@ void CGisListWks::slotCopyItem()
      *
      * As a fix the keys of the selected items are stored temporarily and
      * later used to retrieve the item on the workspace via CGisWidget::getItemByKey()
-     * again. This is allways safe.
+     * again. This is always safe.
      */
     QList<QTreeWidgetItem*> items = selectedItems();
     QList<IGisItem::key_t>  keys;
@@ -1380,6 +1438,17 @@ void CGisListWks::slotRangeTrk()
     }
 }
 
+void CGisListWks::slotCopyTrkWithWpt()
+{
+    CGisListWksEditLock lock(false, IGisItem::mutexItems);
+
+    CGisItemTrk * gisItem = dynamic_cast<CGisItemTrk*>(currentItem());
+    if(gisItem != nullptr)
+    {
+        CGisWidget::self().copyTrkWithWptByKey(gisItem->getKey());
+    }
+}
+
 void CGisListWks::slotFocusRte(bool on)
 {
     CGisListWksEditLock lock(true, IGisItem::mutexItems);
@@ -1453,23 +1522,23 @@ void CGisListWks::slotAddEmptyProject()
     CGisListWksEditLock lock(false, IGisItem::mutexItems);
 
     QString key, name;
-    CSelectProjectDialog::type_e type;
+    IGisProject::type_e type;
     CSelectProjectDialog dlg(key, name, type, nullptr);
     dlg.exec();
-    if(name.isEmpty() && (type != CSelectProjectDialog::eTypeDb))
+    if(name.isEmpty() && (type != IGisProject::eTypeDb))
     {
         return;
     }
 
-    if(type == CSelectProjectDialog::eTypeGpx)
+    if(type == IGisProject::eTypeGpx)
     {
         new CGpxProject(name, this);
     }
-    else if(type == CSelectProjectDialog::eTypeQms)
+    else if(type == IGisProject::eTypeQms)
     {
         new CQmsProject(name, this);
     }
-    else if(type == CSelectProjectDialog::eTypeDb)
+    else if(type == IGisProject::eTypeDb)
     {
         quint64 idParent;
         QString db;
@@ -1664,6 +1733,11 @@ bool CGisListWks::event(QEvent * e)
             CDBProject * project =  getProjectById(evt->id, evt->db);
             if(project && project->askBeforClose())
             {
+                /*
+                    Tell the DB view that we aborted to hide the folder by posting it's
+                    current status.
+                 */
+                project->postStatus(false);
                 return false;
             }
             delete project;
@@ -1791,3 +1865,47 @@ void CGisListWks::slotSyncDB()
         project->update();
     }
 }
+
+void CGisListWks::slotSetSortMode(IGisProject::sorting_folder_e mode, bool checked)
+{
+    if(!checked || blockSorting)
+    {
+        return;
+    }
+
+
+    IGisProject * project = dynamic_cast<IGisProject*>(currentItem());
+    if(project != nullptr)
+    {
+        project->setSortingFolder(mode);
+    }
+}
+
+
+void CGisListWks::slotCopyProject()
+{
+    CGisListWksEditLock lock(true, IGisItem::mutexItems);
+
+    QList<IGisItem::key_t>  keys;
+
+    for(QTreeWidgetItem * item : selectedItems())
+    {
+        IGisProject * project = dynamic_cast<IGisProject*>(item);
+        if(project == nullptr)
+        {
+            continue;
+        }
+
+        const int N = project->childCount();
+        for(int i = 0; i < N; i++)
+        {
+            IGisItem * item = dynamic_cast<IGisItem*>(project->child(i));
+            if(item != nullptr)
+            {
+                keys << item->getKey();
+            }
+        }
+    }
+
+    CGisWidget::self().copyItemsByKey(keys);
+}
