@@ -19,6 +19,8 @@
 #ifndef CGISLISTWKS_H
 #define CGISLISTWKS_H
 
+#include "gis/prj/IGisProject.h"
+
 #include <QPointer>
 #include <QSqlDatabase>
 #include <QTreeWidget>
@@ -29,6 +31,7 @@ class CSearchGoogle;
 class IGisProject;
 class CDBProject;
 class IDeviceWatcher;
+class QActionGroup;
 
 class CGisListWks : public QTreeWidget
 {
@@ -72,6 +75,7 @@ private slots:
     void slotContextMenu(const QPoint& point);
     void slotSaveProject();
     void slotSaveAsProject();
+    void slotSaveAsStrictGpx11Project();
     void slotEditPrj();
     void slotCloseProject();
     void slotDeleteProject();
@@ -89,6 +93,7 @@ private slots:
     void slotReverseTrk();
     void slotCombineTrk();
     void slotRangeTrk();
+    void slotCopyTrkWithWpt();
     void slotFocusRte(bool on);
     void slotCalcRte();
     void slotResetRte();
@@ -103,6 +108,8 @@ private slots:
     void slotSyncDevWks();
     void slotRteFromWpt();
     void slotSyncDB();
+    void slotSetSortMode(IGisProject::sorting_folder_e mode, bool checked);
+    void slotCopyProject();
 
 
 private:
@@ -112,20 +119,28 @@ private:
     void migrateDB1to2();
     void migrateDB2to3();
     void setVisibilityOnMap(bool visible);
+    QAction * addSortAction(QMenu * menu, QActionGroup *actionGroup, const QString& icon, const QString& text, IGisProject::sorting_folder_e mode);
 
     QSqlDatabase db;
 
     QMenu * menuProjectWks;
     QAction  * actionSave;
     QAction  * actionSaveAs;
+    QAction  * actionSaveAsStrict;
+    QAction  * actionCopyPrj;
     QAction  * actionEditPrj;
     QAction  * actionCloseProj;
     QAction  * actionShowOnMap;
     QAction  * actionHideFrMap;
     QAction  * actionSyncWksDev;
     QAction  * actionSyncDB;
+    QAction  * actionSortByTime;
+    QAction  * actionSortByName;
 
 
+
+    QActionGroup * actionGroup;
+
     QMenu * menuProjectDev;
     QAction  * actionDelProj;
     QAction  * actionSyncDevWks;
@@ -148,6 +163,7 @@ private:
     QAction * actionReverseTrk;
     QAction * actionCombineTrk;
     QAction * actionRangeTrk;
+    QAction * actionCopyTrkWithWpt;
     QAction * actionFocusRte;
     QAction * actionCalcRte;
     QAction * actionResetRte;
@@ -164,6 +180,8 @@ private:
     qint32 saveEvery = 5;
 
     IDeviceWatcher * deviceWatcher = nullptr;
+
+    bool blockSorting = false;
 };
 
 #endif //CGISLISTWKS_H
