@@ -60,6 +60,7 @@ CGisWidget::CGisWidget(QMenu *menuProject, QWidget *parent)
 
     connect(treeWks, &CGisListWks::sigChanged, this, &CGisWidget::sigChanged);
     connect(treeDB,  &CGisListDB::sigChanged,  this, &CGisWidget::slotHelpText);
+    connect(sliderOpacity, &QSlider::valueChanged, this, &CGisWidget::slotSetGisLayerOpacity);
 
     slotHelpText();
 
@@ -80,6 +81,10 @@ CGisWidget::~CGisWidget()
     delete treeWks;
 }
 
+void CGisWidget::setOpacity(qreal val)
+{
+    sliderOpacity->setValue(val * 100);
+}
 void CGisWidget::postEventForWks(QEvent * event)
 {
     QCoreApplication::postEvent(treeWks, event);
@@ -148,6 +153,16 @@ void CGisWidget::slotHelpText()
     frameHelp->setVisible(treeDB->topLevelItemCount() == 0);
 }
 
+void CGisWidget::slotSetGisLayerOpacity(int val)
+{
+    CCanvas::gisLayerOpacity = qreal(val)/100;
+    CCanvas * canvas = CMainWindow::self().getVisibleCanvas();
+    if(canvas != nullptr)
+    {
+        canvas->update();
+    }
+}
+
 void CGisWidget::slotSaveAll()
 {
     CCanvas::setOverrideCursor(Qt::WaitCursor, "slotSaveAll");
@@ -175,7 +190,7 @@ void CGisWidget::slotSaveAll()
 IGisProject * CGisWidget::selectProject()
 {
     QString key, name;
-    CSelectProjectDialog::type_e type;
+    IGisProject::type_e type = IGisProject::eTypeQms;
 
     CSelectProjectDialog dlg(key, name, type, treeWks);
     dlg.exec();
@@ -197,7 +212,7 @@ IGisProject * CGisWidget::selectProject()
             }
         }
     }
-    else if(type == CSelectProjectDialog::eTypeDb)
+    else if(type == IGisProject::eTypeDb)
     {
         quint64 idParent;
         QString db;
@@ -222,21 +237,28 @@ IGisProject * CGisWidget::selectProject()
 
         if(evt.idChild)
         {
-            while(nullptr == project)
+            CDBProject * p = nullptr;
+            while(nullptr == p)
             {
                 QApplication::processEvents(QEventLoop::WaitForMoreEvents|QEventLoop::ExcludeUserInputEvents, 100);
-                project = treeWks->getProjectById(evt.idChild, db);
+                p = dynamic_cast<CDBProject*>(treeWks->getProjectById(evt.idChild, db));
             }
+            /*
+               Creating a project usually does initiate an info request. However as the project isn't in the workspace
+               the moment we create it, the request will fail. That is why we send the info now.
+             */
+            p->postStatus(false);
+            project = p;
         }
     }
     else if(!name.isEmpty())
     {
         QMutexLocker lock(&IGisItem::mutexItems);
-        if(type == CSelectProjectDialog::eTypeGpx)
+        if(type == IGisProject::eTypeGpx)
         {
             project = new CGpxProject(name, treeWks);
         }
-        else if (type == CSelectProjectDialog::eTypeQms)
+        else if (type == IGisProject::eTypeQms)
         {
             project = new CQmsProject(name, treeWks);
         }
@@ -756,6 +778,30 @@ void CGisWidget::rangeTrkByKey(const IGisItem::key_t& key)
     }
 }
 
+void CGisWidget::copyTrkWithWptByKey(const IGisItem::key_t &key)
+{
+    QList<IGisItem::key_t> keys;
+
+    CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(CGisWidget::self().getItemByKey(key));
+    if(nullptr != trk)
+    {
+        keys << key;
+
+        const CTrackData& t = trk->getTrackData();
+        for(const CTrackData::trkpt_t& trkpt : t)
+        {
+            if(trkpt.isHidden() || trkpt.keyWpt.item.isEmpty())
+            {
+                continue;
+            }
+
+            keys << trkpt.keyWpt;
+        }
+
+        copyItemsByKey(keys);
+    }
+}
+
 void CGisWidget::editRteByKey(const IGisItem::key_t& key)
 {
     QMutexLocker lock(&IGisItem::mutexItems);
