@@ -25,6 +25,7 @@
 #include "gis/CGisWidget.h"
 #include "gis/IGisItem.h"
 #include "gis/db/macros.h"
+#include "gis/ovl/CGisItemOvlArea.h"
 #include "gis/prj/IGisProject.h"
 #include "gis/rte/CGisItemRte.h"
 #include "gis/trk/CGisItemTrk.h"
@@ -282,7 +283,7 @@ QString IGisItem::getNameEx() const
 void IGisItem::updateDecoration(quint32 enable, quint32 disable)
 {
     // update text and icon
-    setToolTip(CGisListWks::eColumnName,getInfo());
+    setToolTip(CGisListWks::eColumnName,getInfo(true, false));
     setText(CGisListWks::eColumnName, getName());
     setSymbol();
 
@@ -653,9 +654,15 @@ QString IGisItem::removeHtml(const QString &str)
     return html.toPlainText();
 }
 
-QString IGisItem::html2Dev(const QString& str)
+QString IGisItem::html2Dev(const QString& str, bool strictGpx11)
 {
-    return isOnDevice() == IDevice::eTypeGarmin ? removeHtml(str) : str;
+    // device or not, an empty text should never be enclosed in HTML tags
+    if(removeHtml(str).simplified().isEmpty())
+    {
+        return "";
+    }
+
+    return (isOnDevice() == IDevice::eTypeGarmin) || strictGpx11 ? removeHtml(str) : str;
 }
 
 QString IGisItem::toLink(bool isReadOnly, const QString& href, const QString& str, const QString &key)
@@ -837,3 +844,33 @@ bool IGisItem::getNameAndProject(QString &name, IGisProject *&project, const QSt
     project = CGisWidget::self().selectProject();
     return nullptr != project;
 }
+
+IGisItem * IGisItem::newGisItem(quint32 type, quint64 id, QSqlDatabase& db, IGisProject * project)
+{
+    IGisItem *item = nullptr;
+
+    // load item from database
+    switch(type)
+    {
+    case IGisItem::eTypeWpt:
+        item = new CGisItemWpt(id, db, project);
+        break;
+
+    case IGisItem::eTypeTrk:
+        item = new CGisItemTrk(id, db, project);
+        break;
+
+    case IGisItem::eTypeRte:
+        item = new CGisItemRte(id, db, project);
+        break;
+
+    case IGisItem::eTypeOvl:
+        item = new CGisItemOvlArea(id, db, project);
+        break;
+
+    default:
+        ;
+    }
+
+    return item;
+}
