@@ -196,7 +196,7 @@ public:
        @brief Save the item's data into a GPX structure
        @param gpx       the files <gpx> tag to attach the data to
      */
-    virtual void save(QDomNode& gpx) = 0;
+    virtual void save(QDomNode& gpx, bool strictGpx11) = 0;
 
     /**
        @brief Get key string to identify object
@@ -250,13 +250,18 @@ public:
 
     /**
        @brief Get a short string with the items properties to be displayed in tool tips or similar
+
+       @param showName          set true if the first line should be the item's name
+       @apram showFullText      set false to get a 200 characters limited info text
+
        @return A string object.
      */
-    virtual QString getInfo(bool allowEdit = false) const = 0;
+    virtual QString getInfo(bool showName, bool showFullText) const = 0;
 
     virtual const QString& getComment() const = 0;
     virtual const QString& getDescription() const = 0;
     virtual const QList<link_t>& getLinks() const = 0;
+    virtual QDateTime getTimestamp() const = 0;
 
 
     virtual void setComment(const QString& str) = 0;
@@ -357,7 +362,7 @@ public:
 
     /**
        @brief Check if there are any pending unsaved changes
-       @return True if the are changes to be safed
+       @return True if the are changes to be saved
      */
     bool isChanged() const;
 
@@ -452,7 +457,7 @@ public:
      */
     static QString removeHtml(const QString &str);
     /**
-       @brief Create a HTML formated text with comment, description and link section.
+       @brief Create a HTML formatted text with comment, description and link section.
 
        Depending on the isReadOnly flag the section headers are links to trigger a function
 
@@ -465,7 +470,7 @@ public:
      */
     static QString createText(bool isReadOnly, const QString& cmt, const QString& desc, const QList<link_t>& links, const QString& key = "");
     /**
-       @brief Create a HTML formated text with description and link section.
+       @brief Create a HTML formatted text with description and link section.
 
        Depending on the isReadOnly flag the section headers are links to trigger a function
 
@@ -477,7 +482,7 @@ public:
      */
     static QString createText(bool isReadOnly, const QString& desc, const QList<link_t>& links, const QString& key = "");
     /**
-       @brief Create a HTML formated text with a link.
+       @brief Create a HTML formatted text with a link.
 
        Depending on the isReadOnly flag the section headers are links to trigger a function
 
@@ -501,6 +506,10 @@ public:
      */
     static bool getNameAndProject(QString &name, IGisProject *&project, const QString &itemtype);
 
+
+    static IGisItem * newGisItem(quint32 type, quint64 id, QSqlDatabase& db, IGisProject * project);
+
+
     /// a no key value that can be used to nullify references.
     const static QString noKey;
 
@@ -522,7 +531,7 @@ protected:
     /// read waypoint data from an XML snippet
     void readWpt(const QDomNode& xml, wpt_t &wpt);
     /// write waypoint data to an XML snippet
-    void writeWpt(QDomElement &xml, const wpt_t &wpt);
+    void writeWpt(QDomElement &xml, const wpt_t &wpt, bool strictGpx11);
     /// generate a unique key from item's data
     virtual void genKey() const;
     /// setup the history structure right after the creation of the item
@@ -551,7 +560,7 @@ protected:
        @param str   a string
        @return A string with HTML removed depending on the device
      */
-    QString html2Dev(const QString& str);
+    QString html2Dev(const QString& str, bool strictGpx11);
 
     /// see flags_e for possible flags
     quint32 flags = 0;
