@@ -24,6 +24,7 @@
 #include "gis/db/macros.h"
 #include "gis/gpx/CGpxProject.h"
 #include "gis/ovl/CGisItemOvlArea.h"
+#include "gis/prj/CDetailsPrj.h"
 #include "gis/qms/CQmsProject.h"
 #include "gis/rte/CGisItemRte.h"
 #include "gis/trk/CGisItemTrk.h"
@@ -166,8 +167,11 @@ void CDBProject::postStatus(bool updateLostFound)
         query.prepare("SELECT COUNT(*) FROM folder2item WHERE parent=:parent");
         query.bindValue(":parent", getId());
         QUERY_EXEC();
+        query.next();
 
-        if(query.next() && (query.value(0).toInt() != info->keysChildren.count()))
+        const int nChildrenAttached = query.value(0).toInt();
+
+        if((nChildrenAttached != 0) && (nChildrenAttached != info->keysChildren.count()))
         {
             checkState = Qt::PartiallyChecked;
         }
@@ -194,12 +198,12 @@ void CDBProject::postStatus(bool updateLostFound)
 }
 
 
-int CDBProject::checkForAction2(IGisItem * item, quint64 &idItem, QString& hashItem, QSqlQuery &query)
+int CDBProject::checkForAction2(IGisItem * item, quint64 &itemId, QString& hashItem, QSqlQuery &query)
 {
     int action = eActionNone;
 
     query.prepare("SELECT hash, last_user, last_change FROM items WHERE id=:id");
-    query.bindValue(":id", idItem);
+    query.bindValue(":id", itemId);
     QUERY_EXEC(throw eReasonQueryFail);
 
     if(query.next())
@@ -273,12 +277,13 @@ void CDBProject::updateItem(IGisItem *&item, quint64 idItem, QSqlQuery &query)
 
     QString hashInDb = item->getLastDatabaseHash();
 
-    query.prepare("UPDATE items SET type=:type, keyqms=:keyqms, icon=:icon, name=:name, comment=:comment, data=:data, hash=:hash WHERE id=:id AND hash=:oldhash");
+    query.prepare("UPDATE items SET type=:type, keyqms=:keyqms, icon=:icon, name=:name, date=:date, comment=:comment, data=:data, hash=:hash WHERE id=:id AND hash=:oldhash");
     query.bindValue(":type",    item->type());
     query.bindValue(":keyqms",  item->getKey().item);
     query.bindValue(":icon",    buffer.data());
     query.bindValue(":name",    item->getName());
-    query.bindValue(":comment", item->getInfo());
+    query.bindValue(":date",    item->getTimestamp());
+    query.bindValue(":comment", item->getInfo(true, true));
     query.bindValue(":data",    data);
     query.bindValue(":hash",    item->getHash());
     query.bindValue(":id",      idItem);
@@ -320,12 +325,13 @@ void CDBProject::updateItem(IGisItem *&item, quint64 idItem, QSqlQuery &query)
         {
             // hashInDb has been updated by checkForAction2() by the one stored in the database
             // therefore the update should succeed now.
-            query.prepare("UPDATE items SET type=:type, keyqms=:keyqms, icon=:icon, name=:name, comment=:comment, data=:data, hash=:hash WHERE id=:id AND hash=:oldhash");
+            query.prepare("UPDATE items SET type=:type, keyqms=:keyqms, icon=:icon, name=:name, date=:date, comment=:comment, data=:data, hash=:hash WHERE id=:id AND hash=:oldhash");
             query.bindValue(":type",    item->type());
             query.bindValue(":keyqms",  item->getKey().item);
             query.bindValue(":icon",    buffer.data());
             query.bindValue(":name",    item->getName());
-            query.bindValue(":comment", item->getInfo());
+            query.bindValue(":date",    item->getTimestamp());
+            query.bindValue(":comment", item->getInfo(true, true));
             query.bindValue(":data",    data);
             query.bindValue(":hash",    item->getHash());
             query.bindValue(":id",      idItem);
@@ -372,12 +378,13 @@ quint64 CDBProject::insertItem(IGisItem * item, QSqlQuery &query)
     pixmap.save(&buffer, "PNG");
     buffer.seek(0);
 
-    query.prepare("INSERT INTO items (type, keyqms, icon, name, comment, data, hash) VALUES (:type, :keyqms, :icon, :name, :comment, :data, :hash)");
+    query.prepare("INSERT INTO items (type, keyqms, icon, name, date, comment, data, hash) VALUES (:type, :keyqms, :icon, :name, :date, :comment, :data, :hash)");
     query.bindValue(":type",    item->type());
     query.bindValue(":keyqms",  item->getKey().item);
     query.bindValue(":icon",    buffer.data());
     query.bindValue(":name",    item->getName());
-    query.bindValue(":comment", item->getInfo());
+    query.bindValue(":date",    item->getTimestamp());
+    query.bindValue(":comment", item->getInfo(true, true));
     query.bindValue(":data",    data);
     query.bindValue(":hash",    item->getHash());
     QUERY_EXEC(throw eReasonQueryFail);
@@ -400,12 +407,12 @@ quint64 CDBProject::insertItem(IGisItem * item, QSqlQuery &query)
     return idItem;
 }
 
-int CDBProject::checkForAction1(IGisItem * item, quint64& idItem, int& lastResult, QSqlQuery &query)
+int CDBProject::checkForAction1(IGisItem * item, quint64& itemId, int& lastResult, QSqlQuery &query)
 {
     int action = eActionNone;
 
     // test if item exists in database
-    quint32 typeItem = 0;
+    quint32 itemType = 0;
     query.prepare("SELECT id, type FROM items WHERE keyqms=:keyqms");
     query.bindValue(":keyqms", item->getKey().item);
     QUERY_EXEC(throw eReasonQueryFail);
@@ -413,13 +420,13 @@ int CDBProject::checkForAction1(IGisItem * item, quint64& idItem, int& lastResul
 
     if(query.next())
     {
-        idItem      = query.value(0).toULongLong();
-        typeItem    = query.value(1).toUInt();
+        itemId      = query.value(0).toULongLong();
+        itemType    = query.value(1).toUInt();
 
         // check if relation already exists.
         query.prepare("SELECT id FROM folder2item WHERE parent=:parent AND child=:child");
         query.bindValue(":parent", id);
-        query.bindValue(":child", idItem);
+        query.bindValue(":child", itemId);
         QUERY_EXEC(throw eReasonQueryFail);
 
         if(!query.next())
@@ -430,31 +437,7 @@ int CDBProject::checkForAction1(IGisItem * item, quint64& idItem, int& lastResul
             if(lastResult == CSelectSaveAction::eResultNone)
             {
                 // Build the dialog to ask for user action
-
-                IGisItem * item1 = nullptr;
-
-                // load item from database for a compare
-                switch(typeItem)
-                {
-                case IGisItem::eTypeWpt:
-                    item1 = new CGisItemWpt(idItem, db, nullptr);
-                    break;
-
-                case IGisItem::eTypeTrk:
-                    item1 = new CGisItemTrk(idItem, db, nullptr);
-                    break;
-
-                case IGisItem::eTypeRte:
-                    item1 = new CGisItemRte(idItem, db, nullptr);
-                    break;
-
-                case IGisItem::eTypeOvl:
-                    item1 = new CGisItemOvlArea(idItem, db, nullptr);
-                    break;
-
-                default:
-                    ;
-                }
+                IGisItem * item1 = IGisItem::newGisItem(itemType, itemId, db, nullptr);
 
                 if(nullptr == item1)
                 {
@@ -521,7 +504,7 @@ bool CDBProject::save()
     bool success    = true;
     int lastResult  = CSelectSaveAction::eResultNone;
 
-    // check if project is still part of the databasse
+    // check if project is still part of the database
     query.prepare("SELECT keyqms FROM folders WHERE id=:id");
     query.bindValue(":id", id);
     QUERY_EXEC(return false);
@@ -622,10 +605,11 @@ bool CDBProject::save()
     *this >> in;
 
     // update folder entry in database
-    query.prepare("UPDATE folders SET name=:name, comment=:comment, data=:data WHERE id=:id");
+    query.prepare("UPDATE folders SET name=:name, comment=:comment, data=:data, sortmode=:sortmode WHERE id=:id");
     query.bindValue(":name", getName());
     query.bindValue(":comment", getInfo());
     query.bindValue(":data", data);
+    query.bindValue(":sortmode", getSortingFolder());
     query.bindValue(":id", getId());
     QUERY_EXEC(return false);
 
@@ -639,35 +623,18 @@ bool CDBProject::save()
 
 void CDBProject::showItems(CEvtD2WShowItems * evt)
 {
+    bool restoreDlgDetails = false;
     if(evt->addItemsExclusively)
     {
+        restoreDlgDetails = !dlgDetails.isNull();
+        delete dlgDetails;
+
         qDeleteAll(takeChildren());
     }
 
     for(const evt_item_t &item : evt->items)
     {
-        IGisItem * gisItem = nullptr;
-        switch(item.type)
-        {
-        case IGisItem::eTypeWpt:
-            gisItem = new CGisItemWpt(item.id, db, this);
-            break;
-
-        case IGisItem::eTypeTrk:
-            gisItem = new CGisItemTrk(item.id, db, this);
-            break;
-
-        case IGisItem::eTypeRte:
-            gisItem = new CGisItemRte(item.id, db, this);
-            break;
-
-        case IGisItem::eTypeOvl:
-            gisItem = new CGisItemOvlArea(item.id, db, this);
-            break;
-
-        default:
-            ;
-        }
+        IGisItem * gisItem = IGisItem::newGisItem(item.type, item.id, db, this);
 
         /* [Issue #72] Database/Workspace inconsistency in QMS 1.4.0
 
@@ -696,8 +663,14 @@ void CDBProject::showItems(CEvtD2WShowItems * evt)
         }
     }
 
+    sortItems();
     postStatus(false);
     setToolTip(CGisListWks::eColumnName, getInfo());
+
+    if(restoreDlgDetails)
+    {
+        edit();
+    }
 }
 
 void CDBProject::hideItems(CEvtD2WHideItems * evt)
