@@ -16,6 +16,7 @@
 
 **********************************************************************************************/
 
+#include "CMainWindow.h"
 #include "gis/CGisListDB.h"
 #include "gis/CGisWidget.h"
 #include "gis/IGisItem.h"
@@ -23,6 +24,7 @@
 #include "gis/db/CDBFolderOther.h"
 #include "gis/db/CDBFolderProject.h"
 #include "gis/db/CDBItem.h"
+#include "gis/db/CExportDatabase.h"
 #include "gis/db/IDB.h"
 #include "gis/db/IDBFolder.h"
 #include "gis/db/IDBFolderSql.h"
@@ -90,6 +92,22 @@ QString IDBFolder::getDBHost() const
     return db.hostName();
 }
 
+QString IDBFolder::getName() const
+{
+    return text(CGisListDB::eColumnName);
+}
+
+void IDBFolder::setName(const QString& name)
+{
+    QSqlQuery query(db);
+    query.prepare("UPDATE folders SET name=:name WHERE id=:id");
+    query.bindValue(":name", name);
+    query.bindValue(":id", getId());
+    QUERY_EXEC(return );
+
+    setupFromDB();
+}
+
 IDBFolderSql *IDBFolder::getDBFolder()
 {
     if(type() == eTypeDatabase)
@@ -194,13 +212,15 @@ void IDBFolder::update(CEvtW2DAckInfo * info)
 
     QSqlQuery query(db);
     // update text and tooltip
-    query.prepare("SELECT name, comment FROM folders WHERE id=:id");
+    query.prepare("SELECT name, comment, sortmode FROM folders WHERE id=:id");
     query.bindValue(":id", id);
     QUERY_EXEC(return );
     query.next();
 
     setText(CGisListDB::eColumnName, query.value(0).toString());
     setToolTip(CGisListDB::eColumnName, query.value(1).toString());
+    sortMode = query.value(2).toUInt();
+
 
     setChildIndicator();
 
@@ -228,7 +248,7 @@ bool IDBFolder::update()
     }
 
     // Step 1: get basic properties like name and key
-    query.prepare("SELECT keyqms, name, comment FROM folders WHERE id=:id");
+    query.prepare("SELECT keyqms, name, comment, sortmode FROM folders WHERE id=:id");
     query.bindValue(":id", id);
     QUERY_EXEC(return false);
     query.next();
@@ -237,6 +257,7 @@ bool IDBFolder::update()
     key = query.value(0).toString();
     setText(CGisListDB::eColumnName, query.value(1).toString());
     setToolTip(CGisListDB::eColumnName, query.value(2).toString());
+    sortMode = query.value(3).toUInt();
 
     // Step 2: Test for children.
     setChildIndicator();
@@ -254,9 +275,9 @@ bool IDBFolder::update()
      * left overs are the folders to add.
      *
      * Update existing folders. If the update return s false the folder was removed from
-     * the database or an error occured. In both cases remove the folder item.
+     * the database or an error occurred. In both cases remove the folder item.
      *
-     * Collect all items in dbItems. They will be removed and the item list ist rebuilt
+     * Collect all items in dbItems. They will be removed and the item list is rebuilt
      * from scratch.
      */
     QSet<QString>       activeChildren;
@@ -279,7 +300,7 @@ bool IDBFolder::update()
         QTreeWidgetItem * item = child(i);
 
         // test for folder and update folder
-        // remove the folder from the add list as it is allready known
+        // remove the folder from the add list as it is already known
         // if the update returns false register it for removal
         IDBFolder * dbFolder = dynamic_cast<IDBFolder*>(item);
         if(dbFolder != nullptr)
@@ -376,6 +397,7 @@ void IDBFolder::remove()
     CGisWidget::self().postEventForWks(evt1);
 }
 
+
 void IDBFolder::setupFromDB()
 {
     if(id == 0)
@@ -386,7 +408,7 @@ void IDBFolder::setupFromDB()
     QSqlQuery query(db);
 
     // get basic properties like name and key
-    query.prepare("SELECT keyqms, name, comment FROM folders WHERE id=:id");
+    query.prepare("SELECT keyqms, name, comment, sortmode FROM folders WHERE id=:id");
     query.bindValue(":id", id);
     QUERY_EXEC(return );
     query.next();
@@ -394,6 +416,7 @@ void IDBFolder::setupFromDB()
     key = query.value(0).toString();
     setText(CGisListDB::eColumnName, query.value(1).toString());
     setToolTip(CGisListDB::eColumnName, query.value(2).toString());
+    sortMode = query.value(3).toUInt();
 
     // check if folder has child folders (to set expand indicator)
     setChildIndicator();
@@ -428,6 +451,7 @@ void IDBFolder::addChildren(const QSet<QString>& activeChildren, bool skipFolder
         sortChildren(CGisListDB::eColumnName, Qt::AscendingOrder);
     }
 
+    QList<CDBItem*> items;
     // tracks 2nd
     query.prepare("SELECT t1.child FROM folder2item AS t1, items AS t2 WHERE t1.parent = :id AND t2.id = t1.child AND t2.type=:type ORDER BY t2.id");
     query.bindValue(":id", id);
@@ -436,9 +460,11 @@ void IDBFolder::addChildren(const QSet<QString>& activeChildren, bool skipFolder
     while(query.next())
     {
         quint64 idChild = query.value(0).toULongLong();
-        CDBItem * item = new CDBItem(db, idChild, this);
+        CDBItem * item = new CDBItem(db, idChild, nullptr);
         item->setCheckState(CGisListDB::eColumnCheckbox, activeChildren.contains(item->getKey()) ? Qt::Checked : Qt::Unchecked);
+        items << item;
     }
+    addItemsSorted(items);
 
     // routes 3rd
     query.prepare("SELECT t1.child FROM folder2item AS t1, items AS t2 WHERE t1.parent = :id AND t2.id = t1.child AND t2.type=:type ORDER BY t2.id");
@@ -448,9 +474,11 @@ void IDBFolder::addChildren(const QSet<QString>& activeChildren, bool skipFolder
     while(query.next())
     {
         quint64 idChild = query.value(0).toULongLong();
-        CDBItem * item = new CDBItem(db, idChild, this);
+        CDBItem * item = new CDBItem(db, idChild, nullptr);
         item->setCheckState(CGisListDB::eColumnCheckbox, activeChildren.contains(item->getKey()) ? Qt::Checked : Qt::Unchecked);
+        items << item;
     }
+    addItemsSorted(items);
 
     //waypoints 4th
     query.prepare("SELECT t1.child FROM folder2item AS t1, items AS t2 WHERE t1.parent = :id AND t2.id = t1.child AND t2.type=:type ORDER BY t2.id");
@@ -460,9 +488,11 @@ void IDBFolder::addChildren(const QSet<QString>& activeChildren, bool skipFolder
     while(query.next())
     {
         quint64 idChild = query.value(0).toULongLong();
-        CDBItem * item = new CDBItem(db, idChild, this);
+        CDBItem * item = new CDBItem(db, idChild, nullptr);
         item->setCheckState(CGisListDB::eColumnCheckbox, activeChildren.contains(item->getKey()) ? Qt::Checked : Qt::Unchecked);
+        items << item;
     }
+    addItemsSorted(items);
 
     // overlays 5th
     query.prepare("SELECT t1.child FROM folder2item AS t1, items AS t2 WHERE t1.parent = :id AND t2.id = t1.child AND t2.type=:type ORDER BY t2.id");
@@ -472,9 +502,11 @@ void IDBFolder::addChildren(const QSet<QString>& activeChildren, bool skipFolder
     while(query.next())
     {
         quint64 idChild = query.value(0).toULongLong();
-        CDBItem * item = new CDBItem(db, idChild, this);
+        CDBItem * item = new CDBItem(db, idChild, nullptr);
         item->setCheckState(CGisListDB::eColumnCheckbox, activeChildren.contains(item->getKey()) ? Qt::Checked : Qt::Unchecked);
+        items << item;
     }
+    addItemsSorted(items);
 }
 
 void IDBFolder::remove(quint64 idParent, quint64 idFolder)
@@ -548,3 +580,61 @@ void IDBFolder::setChildIndicator()
         setChildIndicatorPolicy(QTreeWidgetItem::DontShowIndicator);
     }
 }
+
+void IDBFolder::addItemsSorted(QList<CDBItem*>& items)
+{
+    sortItems(items);
+    for(CDBItem * item : items)
+    {
+        addChild(item);
+    }
+    items.clear();
+}
+
+bool sortByName(CDBItem * item1, CDBItem * item2)
+{
+    return item1->text(CGisListDB::eColumnName) < item2->text(CGisListDB::eColumnName);
+}
+
+bool sortByTime(CDBItem * item1, CDBItem * item2)
+{
+    return item1->date < item2->date;
+}
+
+void IDBFolder::sortItems(QList<CDBItem*>& items) const
+{
+    switch(sortMode)
+    {
+    case IGisProject::eSortFolderTime:
+        qSort(items.begin(), items.end(), &sortByTime);
+        break;
+
+    case IGisProject::eSortFolderName:
+        qSort(items.begin(), items.end(), &sortByName);
+        break;
+    }
+}
+
+
+bool IDBFolder::isSiblingFrom(IDBFolder * folder) const
+{
+    if(folder->getId() == getId())
+    {
+        return true;
+    }
+
+    IDBFolder * parentFolder = dynamic_cast<IDBFolder*>(parent());
+    if(parentFolder != nullptr)
+    {
+        return parentFolder->isSiblingFrom(folder);
+    }
+
+    return false;
+}
+
+void IDBFolder::exportToGpx()
+{
+    CExportDatabase dlg(getId(), getDb(), CMainWindow::self().getBestWidgetForParent());
+    dlg.exec();
+}
+
