@@ -19,6 +19,8 @@
 #ifndef IDBFOLDER_H
 #define IDBFOLDER_H
 
+#include "gis/prj/IGisProject.h"
+
 #include <QSqlDatabase>
 #include <QTreeWidgetItem>
 
@@ -27,6 +29,7 @@ class CEvtW2DAckInfo;
 class IDBFolderSql;
 class CDBItem;
 
+
 /**
  * @brief Baseclass for all folders in the database view
  */
@@ -59,6 +62,9 @@ public:
 
     QSqlDatabase& getDb(){return db; }
 
+    QString getName() const;
+    void setName(const QString& name);
+
     /**
      * @brief Get the database folder that folder is stored in
      *
@@ -142,6 +148,24 @@ public:
 
     void updateItemsOnWks();
 
+    /**
+       @brief Do a database search.
+
+       This must be overridden by the database folder classes. As a result the query will
+       contain a list of item IDs.
+
+       @param str       The string to search for
+       @param query     The sql query item to use
+     */
+    virtual bool search(const QString& str, QSqlQuery& query)
+    {
+        return false;
+    }
+
+    bool isSiblingFrom(IDBFolder * folder) const;
+
+    void exportToGpx();
+
 protected:
     /**
        @brief Setup all item properties
@@ -175,10 +199,14 @@ protected:
 
     void setChildIndicator();
 
+    void addItemsSorted(QList<CDBItem *> &items);
+    void sortItems(QList<CDBItem *> &items) const;
+
     QSqlDatabase& db;
 
     quint64 id;
     QString key;
+    quint32 sortMode =  IGisProject::eSortFolderTime;
     bool isLoadable;
 };
 
