@@ -23,6 +23,7 @@
 
 class IDBSqlite : public IDB
 {
+    Q_DECLARE_TR_FUNCTIONS(IDBSqlite)
 public:
     IDBSqlite();
     virtual ~IDBSqlite() = default;
@@ -35,6 +36,8 @@ protected:
     bool migrateDB1to2();
     bool migrateDB2to3();
     bool migrateDB3to4();
+    bool migrateDB4to5();
+    bool migrateDB5to6();
 };
 
 #endif //IDBSQLITE_H
