@@ -69,7 +69,7 @@ CGpxProject::CGpxProject(const QString &filename, const IGisProject * project, I
         }
     }
 
-    setupName(QFileInfo(filename).baseName().replace("_", " "));
+    setupName(QFileInfo(filename).completeBaseName().replace("_", " "));
     blockUpdateItems(false);
     setToolTip(CGisListWks::eColumnName, getInfo());
     valid = true;
@@ -99,7 +99,7 @@ void CGpxProject::loadGpx(const QString &filename, CGpxProject *project)
     QFile file(filename);
 
     // if the file does not exist, the filename is assumed to be a name for a new project
-    if(!file.exists())
+    if(!file.exists() || QFileInfo(filename).suffix().toLower() != "gpx")
     {
         project->filename.clear();
         project->setupName(filename);
@@ -158,9 +158,14 @@ void CGpxProject::loadGpx(const QString &filename, CGpxProject *project)
         project->key = xmlExtension.namedItem("ql:key").toElement().text();
     }
 
-    if(xmlExtension.namedItem("ql:sorting").isElement())
+    if(xmlExtension.namedItem("ql:sortingRoadbook").isElement())
     {
-        project->sorting = sorting_e(xmlExtension.namedItem("ql:sorting").toElement().text().toInt());
+        project->sortingRoadbook = sorting_roadbook_e(xmlExtension.namedItem("ql:sortingRoadbook").toElement().text().toInt());
+    }
+
+    if(xmlExtension.namedItem("ql:sortingFolder").isElement())
+    {
+        project->sortingFolder = sorting_folder_e(xmlExtension.namedItem("ql:sortingFolder").toElement().text().toInt());
     }
 
     if(xmlExtension.namedItem("ql:correlation").isElement())
@@ -221,12 +226,13 @@ void CGpxProject::loadGpx(const QString &filename, CGpxProject *project)
         new CGisItemOvlArea(xmlArea, project);
     }
 
-    project->setupName(QFileInfo(filename).baseName().replace("_", " "));
+    project->sortItems();
+    project->setupName(QFileInfo(filename).completeBaseName().replace("_", " "));
     project->setToolTip(CGisListWks::eColumnName, project->getInfo());
     project->valid = true;
 }
 
-bool CGpxProject::saveAs(const QString& fn, IGisProject& project)
+bool CGpxProject::saveAs(const QString& fn, IGisProject& project, bool strictGpx11)
 {
     QString _fn_ = fn;
     QFileInfo fi(_fn_);
@@ -276,7 +282,7 @@ bool CGpxProject::saveAs(const QString& fn, IGisProject& project)
 
     //  ---- start content of gpx
     QDomDocument doc;
-    QDomNode gpx = project.writeMetadata(doc);
+    QDomNode gpx = project.writeMetadata(doc, strictGpx11);
 
     IDevice * device = dynamic_cast<IDevice*>(project.parent());
     if(device)
@@ -302,7 +308,7 @@ bool CGpxProject::saveAs(const QString& fn, IGisProject& project)
             device->saveImages(*item);
         }
 
-        item->save(gpx);
+        item->save(gpx, strictGpx11);
     }
     for(int i = 0; i < project.childCount(); i++)
     {
@@ -311,7 +317,7 @@ bool CGpxProject::saveAs(const QString& fn, IGisProject& project)
         {
             continue;
         }
-        item->save(gpx);
+        item->save(gpx, strictGpx11);
     }
     for(int i = 0; i < project.childCount(); i++)
     {
@@ -320,43 +326,52 @@ bool CGpxProject::saveAs(const QString& fn, IGisProject& project)
         {
             continue;
         }
-        item->save(gpx);
+        item->save(gpx, strictGpx11);
     }
 
-    QDomElement xmlExt = doc.createElement("extensions");
-    gpx.appendChild(xmlExt);
-    for(int i = 0; i < project.childCount(); i++)
+    if(!strictGpx11)
     {
-        CGisItemOvlArea * item = dynamic_cast<CGisItemOvlArea*>(project.child(i));
-        if(nullptr == item)
+        QDomElement xmlExt = doc.createElement("extensions");
+        gpx.appendChild(xmlExt);
+        for(int i = 0; i < project.childCount(); i++)
         {
-            continue;
+            CGisItemOvlArea * item = dynamic_cast<CGisItemOvlArea*>(project.child(i));
+            if(nullptr == item)
+            {
+                continue;
+            }
+            item->save(xmlExt,strictGpx11);
         }
-        item->save(xmlExt);
-    }
 
-    if(!project.getKey().isEmpty())
-    {
-        QDomElement elem = xmlExt.ownerDocument().createElement("ql:key");
-        xmlExt.appendChild(elem);
-        QDomText text = xmlExt.ownerDocument().createTextNode(project.getKey());
-        elem.appendChild(text);
-    }
+        if(!project.getKey().isEmpty())
+        {
+            QDomElement elem = xmlExt.ownerDocument().createElement("ql:key");
+            xmlExt.appendChild(elem);
+            QDomText text = xmlExt.ownerDocument().createTextNode(project.getKey());
+            elem.appendChild(text);
+        }
 
-    {
-        QDomElement elem = xmlExt.ownerDocument().createElement("ql:sorting");
-        xmlExt.appendChild(elem);
-        QDomText text = xmlExt.ownerDocument().createTextNode(QString::number(project.getSorting()));
-        elem.appendChild(text);
-    }
+        {
+            QDomElement elem = xmlExt.ownerDocument().createElement("ql:sortingRoadbook");
+            xmlExt.appendChild(elem);
+            QDomText text = xmlExt.ownerDocument().createTextNode(QString::number(project.getSortingRoadbook()));
+            elem.appendChild(text);
+        }
 
-    {
-        QDomElement elem = xmlExt.ownerDocument().createElement("ql:correlation");
-        xmlExt.appendChild(elem);
-        QDomText text = xmlExt.ownerDocument().createTextNode(QString::number(project.doCorrelation()));
-        elem.appendChild(text);
-    }
+        {
+            QDomElement elem = xmlExt.ownerDocument().createElement("ql:sortingFolder");
+            xmlExt.appendChild(elem);
+            QDomText text = xmlExt.ownerDocument().createTextNode(QString::number(project.getSortingFolder()));
+            elem.appendChild(text);
+        }
 
+        {
+            QDomElement elem = xmlExt.ownerDocument().createElement("ql:correlation");
+            xmlExt.appendChild(elem);
+            QDomText text = xmlExt.ownerDocument().createTextNode(QString::number(project.doCorrelation()));
+            elem.appendChild(text);
+        }
+    }
     //  ---- stop  content of gpx
 
     bool res = true;
@@ -379,7 +394,19 @@ bool CGpxProject::saveAs(const QString& fn, IGisProject& project)
     }
     catch(const QString& msg)
     {
-        QMessageBox::warning(CMainWindow::getBestWidgetForParent(), tr("Saving GIS data failed..."), msg, QMessageBox::Abort);
+        // as saveAs() can be called from the thread that exports a database showing the
+        // message box will crash the app. Therefore we test if the current thread is the
+        // application's main thread. If not we forward the exception.
+        //
+        // Not sure if that is a good concept.
+        if(QThread::currentThread() == qApp->thread())
+        {
+            QMessageBox::warning(CMainWindow::getBestWidgetForParent(), tr("Saving GIS data failed..."), msg, QMessageBox::Abort);
+        }
+        else
+        {
+            throw msg;
+        }
         res = false;
     }
     project.umount();
