@@ -435,7 +435,7 @@ void IGisProject::readMetadata(const QDomNode& xml, metadata_t& metadata)
     }
 }
 
-QDomNode IGisProject::writeMetadata(QDomDocument& doc)
+QDomNode IGisProject::writeMetadata(QDomDocument& doc, bool strictGpx11)
 {
     QDomElement gpx = doc.createElement("gpx");
     doc.appendChild(gpx);
@@ -444,19 +444,30 @@ QDomNode IGisProject::writeMetadata(QDomDocument& doc)
     gpx.setAttribute("creator","QMapShack " VER_STR " http://www.qlandkarte.org/");
     gpx.setAttribute("xmlns",        gpx_ns);
     gpx.setAttribute("xmlns:xsi",    xsi_ns);
-    gpx.setAttribute("xmlns:gpxx",   gpxx_ns);
-    gpx.setAttribute("xmlns:gpxtpx", gpxtpx_ns);
-    gpx.setAttribute("xmlns:wptx1",  wptx1_ns);
-    gpx.setAttribute("xmlns:rmc",    rmc_ns);
-    gpx.setAttribute("xmlns:ql",     ql_ns);
-    gpx.setAttribute("xmlns:tp1",    tp1_ns);
 
-    QString schemaLocation = QString()
-                             + gpx_ns    + " http://www.topografix.com/GPX/1/1/gpx.xsd "
-                             + gpxx_ns   + " http://www.garmin.com/xmlschemas/GpxExtensionsv3.xsd "
-                             + gpxtpx_ns + " http://www.garmin.com/xmlschemas/TrackPointExtensionv1.xsd "
-                             + wptx1_ns  + " http://www.garmin.com/xmlschemas/WaypointExtensionv1.xsd "
-                             + ql_ns     + " http://www.qlandkarte.org/xmlschemas/v1.1/ql-extensions.xsd ";
+    QString schemaLocation;
+    if(!strictGpx11)
+    {
+        gpx.setAttribute("xmlns:gpxx",   gpxx_ns);
+        gpx.setAttribute("xmlns:gpxtpx", gpxtpx_ns);
+        gpx.setAttribute("xmlns:wptx1",  wptx1_ns);
+        gpx.setAttribute("xmlns:rmc",    rmc_ns);
+        gpx.setAttribute("xmlns:ql",     ql_ns);
+        gpx.setAttribute("xmlns:tp1",    tp1_ns);
+
+        schemaLocation = QString()
+                         + gpx_ns    + " http://www.topografix.com/GPX/1/1/gpx.xsd "
+                         + gpxx_ns   + " http://www.garmin.com/xmlschemas/GpxExtensionsv3.xsd "
+                         + gpxtpx_ns + " http://www.garmin.com/xmlschemas/TrackPointExtensionv1.xsd "
+                         + wptx1_ns  + " http://www.garmin.com/xmlschemas/WaypointExtensionv1.xsd "
+                         + ql_ns     + " http://www.qlandkarte.org/xmlschemas/v1.1/ql-extensions.xsd ";
+    }
+    else
+    {
+        schemaLocation = QString()
+                         + gpx_ns    + " http://www.topografix.com/GPX/1/1/gpx.xsd ";
+    }
+
 
     gpx.setAttribute("xsi:schemaLocation", schemaLocation);
 
@@ -548,32 +559,35 @@ void CGisItemWpt::readGpx(const QDomNode& xml)
     }
 }
 
-void CGisItemWpt::save(QDomNode& gpx)
+void CGisItemWpt::save(QDomNode& gpx, bool strictGpx11)
 {
     QDomDocument doc = gpx.ownerDocument();
 
     QDomElement xmlWpt = doc.createElement("wpt");
     gpx.appendChild(xmlWpt);
-    writeWpt(xmlWpt, wpt);
+    writeWpt(xmlWpt, wpt, strictGpx11);
 
-    // write the key as extension tag
-    QDomElement xmlExt  = doc.createElement("extensions");
-    xmlWpt.appendChild(xmlExt);
-    writeXml(xmlExt, "ql:key",    key.item);
-    writeXml(xmlExt, "ql:flags",  flags);
-    writeXml(xmlExt, "ql:bubble", offsetBubble, widthBubble);
-    writeXml(xmlExt, history);
-
-    // write other well known extensions
-    QDomElement wptx1  = doc.createElement("wptx1:WaypointExtension");
-    xmlExt.appendChild(wptx1);
-    writeXml(wptx1, "wptx1:Proximity", proximity);
-
-    if(geocache.hasData /*&& geocache.service == eGC*/)
+    if(!strictGpx11)
     {
-        QDomElement xmlCache = doc.createElement("groundspeak:cache");
-        writeGcExt(xmlCache);
-        xmlWpt.appendChild(xmlCache);
+        // write the key as extension tag
+        QDomElement xmlExt  = doc.createElement("extensions");
+        xmlWpt.appendChild(xmlExt);
+        writeXml(xmlExt, "ql:key",    key.item);
+        writeXml(xmlExt, "ql:flags",  flags);
+        writeXml(xmlExt, "ql:bubble", offsetBubble, widthBubble);
+        writeXml(xmlExt, history);
+
+        // write other well known extensions
+        QDomElement wptx1  = doc.createElement("wptx1:WaypointExtension");
+        xmlExt.appendChild(wptx1);
+        writeXml(wptx1, "wptx1:Proximity", proximity);
+
+        if(geocache.hasData /*&& geocache.service == eGC*/)
+        {
+            QDomElement xmlCache = doc.createElement("groundspeak:cache");
+            writeGcExt(xmlCache);
+            xmlWpt.appendChild(xmlCache);
+        }
     }
 }
 
@@ -701,7 +715,7 @@ void CGisItemWpt::writeGcExt(QDomNode& xmlCache)
 }
 
 
-void CGisItemTrk::readTrk(const QDomNode& xml, trk_t& trk)
+void CGisItemTrk::readTrk(const QDomNode& xml, CTrackData& trk)
 {
     readXml(xml, "name",   trk.name);
     readXml(xml, "cmt",    trk.cmt);
@@ -717,14 +731,14 @@ void CGisItemTrk::readTrk(const QDomNode& xml, trk_t& trk)
     for(int n = 0; n < N; ++n)
     {
         const QDomNode& trkseg = trksegs.item(n);
-        trkseg_t& seg = trk.segs[n];
+        CTrackData::trkseg_t& seg = trk.segs[n];
 
         const QDomNodeList& xmlTrkpts = trkseg.toElement().elementsByTagName("trkpt");
         int M = xmlTrkpts.count();
         seg.pts.resize(M);
         for(int m = 0; m < M; ++m)
         {
-            trkpt_t& trkpt = seg.pts[m];
+            CTrackData::trkpt_t& trkpt = seg.pts[m];
             const QDomNode& xmlTrkpt = xmlTrkpts.item(m);
             readWpt(xmlTrkpt, trkpt);
 
@@ -755,7 +769,7 @@ void CGisItemTrk::readTrk(const QDomNode& xml, trk_t& trk)
 
 
 
-void CGisItemTrk::save(QDomNode& gpx)
+void CGisItemTrk::save(QDomNode& gpx, bool strictGpx11)
 {
     QDomDocument doc = gpx.ownerDocument();
 
@@ -763,40 +777,46 @@ void CGisItemTrk::save(QDomNode& gpx)
     gpx.appendChild(xmlTrk);
 
     writeXml(xmlTrk, "name",   trk.name);
-    writeXml(xmlTrk, "cmt",    html2Dev(trk.cmt));
-    writeXml(xmlTrk, "desc",   html2Dev(trk.desc));
+    writeXml(xmlTrk, "cmt",    html2Dev(trk.cmt, strictGpx11));
+    writeXml(xmlTrk, "desc",   html2Dev(trk.desc, strictGpx11));
     writeXml(xmlTrk, "src",    trk.src);
     writeXml(xmlTrk, "link",   trk.links);
     writeXml(xmlTrk, "number", trk.number);
     writeXml(xmlTrk, "type",   trk.type);
 
-    // write the key as extension tag
-    QDomElement xmlExt  = doc.createElement("extensions");
-    xmlTrk.appendChild(xmlExt);
-    writeXml(xmlExt, "ql:key", key.item);
-    writeXml(xmlExt, "ql:flags", flags);
-    writeXml(xmlExt, history);
+    if(!strictGpx11)
+    {
+        // write the key as extension tag
+        QDomElement xmlExt  = doc.createElement("extensions");
+        xmlTrk.appendChild(xmlExt);
+        writeXml(xmlExt, "ql:key", key.item);
+        writeXml(xmlExt, "ql:flags", flags);
+        writeXml(xmlExt, history);
 
-    // write other well known extensions
-    QDomElement gpxx  = doc.createElement("gpxx:TrackExtension");
-    xmlExt.appendChild(gpxx);
-    writeXml(gpxx, "gpxx:DisplayColor", trk.color);
+        // write other well known extensions
+        QDomElement gpxx  = doc.createElement("gpxx:TrackExtension");
+        xmlExt.appendChild(gpxx);
+        writeXml(gpxx, "gpxx:DisplayColor", trk.color);
+    }
 
-    for(const trkseg_t &seg : trk.segs)
+    for(const CTrackData::trkseg_t &seg : trk.segs)
     {
         QDomElement xmlTrkseg = doc.createElement("trkseg");
         xmlTrk.appendChild(xmlTrkseg);
 
-        for(const trkpt_t &pt : seg.pts)
+        for(const CTrackData::trkpt_t &pt : seg.pts)
         {
             QDomElement xmlTrkpt = doc.createElement("trkpt");
             xmlTrkseg.appendChild(xmlTrkpt);
-            writeWpt(xmlTrkpt, pt);
+            writeWpt(xmlTrkpt, pt, strictGpx11);
 
-            QDomElement xmlExt  = doc.createElement("extensions");
-            xmlTrkpt.appendChild(xmlExt);
-            writeXml(xmlExt, "ql:flags", pt.flags);
-            writeXml(xmlExt, pt.extensions);
+            if(!strictGpx11)
+            {
+                QDomElement xmlExt  = doc.createElement("extensions");
+                xmlTrkpt.appendChild(xmlExt);
+                writeXml(xmlExt, "ql:flags", pt.flags);
+                writeXml(xmlExt, pt.extensions);
+            }
         }
     }
 }
@@ -831,7 +851,7 @@ void CGisItemRte::readRte(const QDomNode& xml, rte_t& rte)
 }
 
 
-void CGisItemRte::save(QDomNode& gpx)
+void CGisItemRte::save(QDomNode& gpx, bool strictGpx11)
 {
     QDomDocument doc = gpx.ownerDocument();
 
@@ -839,23 +859,26 @@ void CGisItemRte::save(QDomNode& gpx)
     gpx.appendChild(xmlRte);
 
     writeXml(xmlRte, "name",   rte.name);
-    writeXml(xmlRte, "cmt",    html2Dev(rte.cmt));
-    writeXml(xmlRte, "desc",   html2Dev(rte.desc));
+    writeXml(xmlRte, "cmt",    html2Dev(rte.cmt, strictGpx11));
+    writeXml(xmlRte, "desc",   html2Dev(rte.desc, strictGpx11));
     writeXml(xmlRte, "src",    rte.src);
     writeXml(xmlRte, "link",   rte.links);
     writeXml(xmlRte, "number", rte.number);
     writeXml(xmlRte, "type",   rte.type);
 
-    // write the key as extension tag
-    QDomElement xmlExt  = doc.createElement("extensions");
-    xmlRte.appendChild(xmlExt);
-    writeXml(xmlExt, "ql:key", key.item);
+    if(!strictGpx11)
+    {
+        // write the key as extension tag
+        QDomElement xmlExt  = doc.createElement("extensions");
+        xmlRte.appendChild(xmlExt);
+        writeXml(xmlExt, "ql:key", key.item);
+    }
 
     for(const rtept_t &pt : rte.pts)
     {
         QDomElement xmlRtept = doc.createElement("rtept");
         xmlRte.appendChild(xmlRtept);
-        writeWpt(xmlRtept, pt);
+        writeWpt(xmlRtept, pt, strictGpx11);
     }
 }
 
@@ -891,7 +914,7 @@ void CGisItemOvlArea::readArea(const QDomNode& xml, area_t& area)
     deriveSecondaryData();
 }
 
-void CGisItemOvlArea::save(QDomNode& gpx)
+void CGisItemOvlArea::save(QDomNode& gpx, bool strictGpx11)
 {
     QDomDocument doc = gpx.ownerDocument();
 
@@ -917,7 +940,7 @@ void CGisItemOvlArea::save(QDomNode& gpx)
     {
         QDomElement xmlPt = doc.createElement("ql:point");
         xmlArea.appendChild(xmlPt);
-        writeWpt(xmlPt, pt);
+        writeWpt(xmlPt, pt, strictGpx11);
     }
 }
 
@@ -960,7 +983,7 @@ void IGisItem::readWpt(const QDomNode& xml, wpt_t& wpt)
 }
 
 
-void IGisItem::writeWpt(QDomElement& xml, const wpt_t& wpt)
+void IGisItem::writeWpt(QDomElement& xml, const wpt_t& wpt, bool strictGpx11)
 {
     QString str;
 
@@ -974,8 +997,8 @@ void IGisItem::writeWpt(QDomElement& xml, const wpt_t& wpt)
     writeXml(xml, "magvar",        wpt.magvar);
     writeXml(xml, "geoidheight",   wpt.geoidheight);
     writeXml(xml, "name",          wpt.name);
-    writeXml(xml, "cmt",           html2Dev(wpt.cmt));
-    writeXml(xml, "desc",          html2Dev(wpt.desc));
+    writeXml(xml, "cmt",           html2Dev(wpt.cmt, strictGpx11));
+    writeXml(xml, "desc",          html2Dev(wpt.desc, strictGpx11));
     writeXml(xml, "src",           wpt.src);
     writeXml(xml, "link",          wpt.links);
     writeXml(xml, "sym",           wpt.sym);
@@ -1019,7 +1042,7 @@ void CDeviceGarmin::createAdventureFromProject(IGisProject * project, const QStr
         CGisItemTrk * track = dynamic_cast<CGisItemTrk*>(project->child(i));
         if(track != nullptr)
         {
-            const CGisItemTrk::trk_t& trk = track->getTrackData();
+            const CTrackData& trk = track->getTrackData();
             if(trk.segs.isEmpty())
             {
                 continue;
@@ -1030,7 +1053,7 @@ void CDeviceGarmin::createAdventureFromProject(IGisProject * project, const QStr
                 continue;
             }
 
-            const CGisItemTrk::trkpt_t& origin = trk.segs.first().pts.first();
+            const CTrackData::trkpt_t& origin = trk.segs.first().pts.first();
 
             QDomElement startPosition = doc.createElement("StartPosition");
             adventure.appendChild(startPosition);
@@ -1040,8 +1063,8 @@ void CDeviceGarmin::createAdventureFromProject(IGisProject * project, const QStr
             writeXml(adventure, "Activity", tr("Unknown"));
             writeXml(adventure, "Distance", track->getTotalDistance());
             writeXml(adventure, "Duration", track->getTotalElapsedSecondsMoving());
-            writeXml(adventure, "Ascent", track->getTotalAscend());
-            writeXml(adventure, "Descent", track->getTotalDescend());
+            writeXml(adventure, "Ascent", track->getTotalAscent());
+            writeXml(adventure, "Descent", track->getTotalDescent());
             writeXml(adventure, "Difficulty", 1);
             writeXml(adventure, "NumRatings", 0);
             writeXml(adventure, "MainTrackId", track->getName());
@@ -1049,29 +1072,25 @@ void CDeviceGarmin::createAdventureFromProject(IGisProject * project, const QStr
             QDomElement waypointOrder = doc.createElement("WaypointOrder");
             adventure.appendChild(waypointOrder);
 
-            for(const CGisItemTrk::trkseg_t& seg : trk.segs)
+            for(const CTrackData::trkpt_t& trkpt : trk)
             {
-                for(const CGisItemTrk::trkpt_t& trkpt : seg.pts)
+                if(trkpt.keyWpt.item.isEmpty())
                 {
-                    if(trkpt.keyWpt.item.isEmpty())
-                    {
-                        continue;
-                    }
-
-                    const CGisItemWpt * wpt = dynamic_cast<CGisItemWpt*>(project->getItemByKey(trkpt.keyWpt));
-                    if(wpt == nullptr)
-                    {
-                        continue;
-                    }
-
-                    QDomElement waypoints = doc.createElement("Waypoints");
-                    waypointOrder.appendChild(waypoints);
-
-                    writeXml(waypoints, "ID", wpt->getName());
-                    writeXml(waypoints, "DistanceFromOrigin", trkpt.distance);
+                    continue;
                 }
-            }
 
+                const CGisItemWpt * wpt = dynamic_cast<CGisItemWpt*>(project->getItemByKey(trkpt.keyWpt));
+                if(wpt == nullptr)
+                {
+                    continue;
+                }
+
+                QDomElement waypoints = doc.createElement("Waypoints");
+                waypointOrder.appendChild(waypoints);
+
+                writeXml(waypoints, "ID", wpt->getName());
+                writeXml(waypoints, "DistanceFromOrigin", trkpt.distance);
+            }
 
             break;
         }
