@@ -376,10 +376,16 @@ IScrOpt * CGisItemOvlArea::getScreenOptions(const QPoint& origin, IMouse * mouse
     return scrOpt;
 }
 
-QString CGisItemOvlArea::getInfo(bool allowEdit) const
+QString CGisItemOvlArea::getInfo(bool showName, bool showFullText) const
 {
     QString unit, val;
-    QString str = "<div style='font-weight: bold;'>" + getName() + "</div>";
+    QString str = "<div>";
+
+    if(showName)
+    {
+        str += "<b>" + getName() + "</b>";
+    }
+
 
     IUnit::self().meter2area(area.area, val, unit);
     str += "<br/>\n" + tr("Area: %1%2").arg(val).arg(unit);
@@ -392,37 +398,35 @@ QString CGisItemOvlArea::getInfo(bool allowEdit) const
             str += "<br/>\n";
         }
 
-        if(desc.count() < 200)
+        if(showFullText || (desc.count() < 300))
         {
             str += desc;
         }
         else
         {
-            str += desc.left(197) + "...";
+            str += desc.left(297) + "...";
         }
     }
-    else
+
+    QString cmt = removeHtml(area.cmt).simplified();
+    if((cmt != desc) && cmt.count())
     {
-        QString cmt = removeHtml(area.cmt).simplified();
-        if(cmt.count())
+        if(!str.isEmpty())
         {
-            if(!str.isEmpty())
-            {
-                str += "<br/>\n";
-            }
+            str += "<br/>\n";
+        }
 
-            if(cmt.count() < 200)
-            {
-                str += cmt;
-            }
-            else
-            {
-                str += cmt.left(197) + "...";
-            }
+        if(showFullText || cmt.count() < 300)
+        {
+            str += cmt;
+        }
+        else
+        {
+            str += cmt.left(297) + "...";
         }
     }
 
-    return str;
+    return str + "</div>";
 }
 
 void CGisItemOvlArea::getPolylineFromData(SGisLine &l)
