@@ -58,7 +58,7 @@ public:
     {
         return colorIdx;
     }
-    QString getInfo(bool allowEdit = false) const override;
+    QString getInfo(bool showName, bool showFullText) const override;
     void getPolylineFromData(SGisLine& l) override;
     const QString& getComment() const override
     {
@@ -85,6 +85,11 @@ public:
         return area.opacity;
     }
 
+    QDateTime getTimestamp() const override
+    {
+        return QDateTime();
+    }
+
     void setName(const QString& str);
     void setColor(size_t idx);
     void setDataFromPolyline(const SGisLine& l) override;
@@ -95,7 +100,7 @@ public:
     void setDescription(const QString& str)   override;
     void setLinks(const QList<link_t>& links) override;
 
-    void save(QDomNode& gpx) override;
+    void save(QDomNode& gpx, bool strictGpx11) override;
     void edit() override;
 
     using IGisItem::drawItem;
