@@ -16,6 +16,7 @@
 
 **********************************************************************************************/
 
+#include "CMainWindow.h"
 #include "gis/IGisItem.h"
 #include "gis/ovl/CGisItemOvlArea.h"
 #include "gis/prj/CDetailsPrj.h"
@@ -118,8 +119,8 @@ void CDetailsPrj::slotSetupGui()
     }
 
     X______________BlockAllSignals______________X(this);
-    comboSort->setCurrentIndex(prj.getSorting());
-    if((prj.getSorting() > IGisProject::eSortTime) && !prj.doCorrelation())
+    comboSort->setCurrentIndex(prj.getSortingRoadbook());
+    if((prj.getSortingRoadbook() > IGisProject::eSortRoadbookNone) && !prj.doCorrelation())
     {
         X_____________UnBlockAllSignals_____________X(this);
 
@@ -131,7 +132,7 @@ void CDetailsPrj::slotSetupGui()
         }
         else
         {
-            comboSort->setCurrentIndex(IGisProject::eSortNone);
+            comboSort->setCurrentIndex(IGisProject::eSortRoadbookNone);
         }
         timerUpdateTime->start();
 
@@ -161,8 +162,16 @@ void CDetailsPrj::slotSetupGui()
     }
     X_____________UnBlockAllSignals_____________X(this);
 
-    textDesc->document()->setTextWidth(textDesc->size().width() - 20);
-    draw(*textDesc->document(), false);
+    CCanvas::setOverrideCursor(Qt::WaitCursor, "CDetailsPrj::slotSetupGui()");
+    // Create a new document, fill it and attach it to the text browser.
+    // This is much faster than to use the current one of the text browser.
+    // According to the docs, the text browser's current document should be
+    // deleted because the text browser is it's parent.
+    QTextDocument * doc = new QTextDocument();
+    doc->setTextWidth(textDesc->size().width() - 20);
+    draw(*doc, false);
+    doc->setParent(textDesc);
+    textDesc->setDocument(doc);
 
     QTabWidget * tabWidget = dynamic_cast<QTabWidget*>(parentWidget() ? parentWidget()->parentWidget() : nullptr);
     if(tabWidget)
@@ -174,22 +183,13 @@ void CDetailsPrj::slotSetupGui()
             tabWidget->setTabText(idx, prj.getName().replace("&", "&&"));
         }
     }
+    CCanvas::restoreOverrideCursor("CDetailsPrj::slotSetupGui()");
     mutex.unlock();
 }
 
 #define ROOT_FRAME_MARGIN 5
 #define CHAR_PER_LINE 130
 
-bool sortTrkByTime(const CGisItemTrk * trk1, const CGisItemTrk * trk2)
-{
-    return trk1->getTimeStart() < trk2->getTimeStart();
-}
-
-bool sortWptByTime(const CGisItemWpt * wpt1, const CGisItemWpt * wpt2)
-{
-    return wpt1->getTime() < wpt2->getTime();
-}
-
 void CDetailsPrj::draw(QTextDocument& doc, bool printable)
 {
     int w = doc.textWidth();
@@ -197,10 +197,7 @@ void CDetailsPrj::draw(QTextDocument& doc, bool printable)
 
     QFontMetrics fm(QFont(font().family(),12));
     int pointSize = ((10 * (w - 2 * ROOT_FRAME_MARGIN)) / (CHAR_PER_LINE *  fm.width("X")));
-    if(pointSize == 0)
-    {
-        return;
-    }
+    pointSize = qMax(pointSize,CMainWindow::self().getMapFont().pointSize());
 
     QFont f = textDesc->font();
     f.setPointSize(pointSize);
@@ -342,7 +339,7 @@ void CDetailsPrj::draw(QTextDocument& doc, bool printable)
     int n=1;
     PROGRESS_SETUP(tr("Build diary..."), 0, nItems, this);
 
-    if(comboSort->currentIndex() > IGisProject::eSortTime)
+    if(comboSort->currentIndex() > IGisProject::eSortRoadbookNone)
     {
         drawByTrack(cursor, trks, wpts, progress, n, isReadOnly);
     }
@@ -378,7 +375,7 @@ void CDetailsPrj::drawInfo(QTextCursor& cursor, bool isReadOnly)
 void CDetailsPrj::drawTrackSummary(QTextCursor& cursor, const QList<CGisItemTrk*> trks, bool isReadOnly)
 {
     quint32 flags = 0;
-    QVector<CActivityTrk::activity_summary_t> summaries(CGisItemTrk::trkpt_t::eActMaxNum + 1);
+    QMap<quint32, CActivityTrk::activity_summary_t> summaries;
     for(const CGisItemTrk* trk : trks)
     {
         const CActivityTrk& activities = trk->getActivities();
@@ -435,12 +432,6 @@ void CDetailsPrj::drawByGroup(QTextCursor &cursor, QList<CGisItemTrk*>& trks, QL
 {
     int cnt, w = cursor.document()->textWidth();
 
-    if(comboSort->currentIndex() == IGisProject::eSortTime)
-    {
-        qSort(trks.begin(), trks.end(), sortTrkByTime);
-        qSort(wpts.begin(), wpts.end(), sortWptByTime);
-    }
-
     if(!wpts.isEmpty())
     {
         cursor.insertHtml(tr("<h2>Waypoints</h2>"));
@@ -459,7 +450,7 @@ void CDetailsPrj::drawByGroup(QTextCursor &cursor, QList<CGisItemTrk*>& trks, QL
             PROGRESS(n++, return );
 
             addIcon(table, eSym1, cnt, wpt, printable);
-            table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(wpt->getInfo());
+            table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(wpt->getInfo(true, false));
             table->cellAt(cnt,eComment1).firstCursorPosition().insertHtml(IGisItem::createText(wpt->isReadOnly()||printable, wpt->getComment(), wpt->getDescription(), wpt->getLinks(), wpt->getKey().item));
             cnt++;
         }
@@ -492,7 +483,7 @@ void CDetailsPrj::drawByGroup(QTextCursor &cursor, QList<CGisItemTrk*>& trks, QL
 
             if(w1 < 300)
             {
-                table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(trk->getInfo());
+                table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(trk->getInfo(true, false));
 
                 QTextTable * table1 = table->cellAt(cnt,eInfo1).lastCursorPosition().insertTable(1, 2, fmtTableInfo);
 
@@ -508,7 +499,7 @@ void CDetailsPrj::drawByGroup(QTextCursor &cursor, QList<CGisItemTrk*>& trks, QL
             {
                 QTextTable * table1 = table->cellAt(cnt,eInfo1).firstCursorPosition().insertTable(1, 3, fmtTableInfo);
 
-                table1->cellAt(0,0).firstCursorPosition().insertHtml(trk->getInfo());
+                table1->cellAt(0,0).firstCursorPosition().insertHtml(trk->getInfo(true, false));
 
                 QImage profile(w1,h1,QImage::Format_ARGB32);
                 getTrackProfile(trk, profile);
@@ -533,26 +524,22 @@ struct wpt_info_t
 {
     IGisItem::key_t key;
     qreal distance1 = NOFLOAT;
-    qreal ascend1 = NOFLOAT;
-    qreal descend1 = NOFLOAT;
+    qreal ascent1 = NOFLOAT;
+    qreal descent1 = NOFLOAT;
 
     qreal distance2 = NOFLOAT;
-    qreal ascend2 = NOFLOAT;
-    qreal descend2 = NOFLOAT;
+    qreal ascent2 = NOFLOAT;
+    qreal descent2 = NOFLOAT;
 
     qreal distance3 = NOFLOAT;
-    qreal ascend3 = NOFLOAT;
-    qreal descend3 = NOFLOAT;
+    qreal ascent3 = NOFLOAT;
+    qreal descent3 = NOFLOAT;
 };
 
 void CDetailsPrj::drawByTrack(QTextCursor& cursor, QList<CGisItemTrk *> &trks, QList<CGisItemWpt *> &wpts, CProgressDialog &progress, int &n, bool printable)
 {
     int cnt, w = cursor.document()->textWidth();
 
-    if(comboSort->currentIndex() == IGisProject::eSortTime)
-    {
-        qSort(trks.begin(), trks.end(), sortTrkByTime);
-    }
 
     const qreal w1 = qRound(w/3.5 > 300 ? 300 : w/3.5);
     const qreal h1 = qRound(w1/2.0);
@@ -560,40 +547,37 @@ void CDetailsPrj::drawByTrack(QTextCursor& cursor, QList<CGisItemTrk *> &trks, Q
 
     for(CGisItemTrk * trk : trks)
     {
-        const CGisItemTrk::trkpt_t* lastTrkpt = nullptr;
+        const CTrackData::trkpt_t* lastTrkpt = nullptr;
         wpt_info_t * lastWptInfo = nullptr;
         QList<wpt_info_t> wptInfo;
-        const CGisItemTrk::trk_t& t = trk->getTrackData();
-        for(const CGisItemTrk::trkseg_t& seg : t.segs)
+        const CTrackData& t = trk->getTrackData();
+        for(const CTrackData::trkpt_t& trkpt : t)
         {
-            for(const CGisItemTrk::trkpt_t& trkpt : seg.pts)
+            if(trkpt.isHidden() || trkpt.keyWpt.item.isEmpty())
             {
-                if((trkpt.flags & CGisItemTrk::trkpt_t::eHidden) || trkpt.keyWpt.item.isEmpty())
-                {
-                    continue;
-                }
-
-                wptInfo << wpt_info_t();
-                wpt_info_t& info = wptInfo.last();
-                info.key        = trkpt.keyWpt;
-                info.distance1  = trkpt.distance;
-                info.ascend1    = trkpt.ascend;
-                info.descend1   = trkpt.descend;
-
-                if(lastWptInfo != nullptr)
-                {
-                    lastWptInfo->distance2  = trkpt.distance - lastTrkpt->distance;
-                    lastWptInfo->ascend2    = trkpt.ascend   - lastTrkpt->ascend;
-                    lastWptInfo->descend2   = trkpt.descend  - lastTrkpt->descend;
-                }
-
-                info.distance3  = trk->getTotalDistance() - trkpt.distance;
-                info.ascend3    = trk->getTotalAscend() - trkpt.ascend;
-                info.descend3   = trk->getTotalDescend() - trkpt.descend;
-
-                lastTrkpt       = &trkpt;
-                lastWptInfo     = &wptInfo.last();
+                continue;
             }
+
+            wptInfo << wpt_info_t();
+            wpt_info_t& info = wptInfo.last();
+            info.key        = trkpt.keyWpt;
+            info.distance1  = trkpt.distance;
+            info.ascent1    = trkpt.ascent;
+            info.descent1   = trkpt.descent;
+
+            if(lastWptInfo != nullptr)
+            {
+                lastWptInfo->distance2  = trkpt.distance - lastTrkpt->distance;
+                lastWptInfo->ascent2    = trkpt.ascent   - lastTrkpt->ascent;
+                lastWptInfo->descent2   = trkpt.descent  - lastTrkpt->descent;
+            }
+
+            info.distance3  = trk->getTotalDistance() - trkpt.distance;
+            info.ascent3    = trk->getTotalAscent() - trkpt.ascent;
+            info.descent3   = trk->getTotalDescent() - trkpt.descent;
+
+            lastTrkpt       = &trkpt;
+            lastWptInfo     = &wptInfo.last();
         }
 
         cursor.insertHtml(QString("<h2>%1</h2>").arg(trk->getName()));
@@ -617,7 +601,7 @@ void CDetailsPrj::drawByTrack(QTextCursor& cursor, QList<CGisItemTrk *> &trks, Q
             if(wpt != nullptr)
             {
                 addIcon(table, eSym2, cnt, wpt, printable);
-                table->cellAt(cnt,eInfo2).firstCursorPosition().insertHtml(wpt->getInfo());
+                table->cellAt(cnt,eInfo2).firstCursorPosition().insertHtml(wpt->getInfo(true, false));
 
                 QTextTable * table1 = table->cellAt(cnt,eData2).lastCursorPosition().insertTable(1, 2, fmtTableInfo);
 
@@ -637,21 +621,21 @@ void CDetailsPrj::drawByTrack(QTextCursor& cursor, QList<CGisItemTrk *> &trks, Q
 
                 text += "<tr>";
                 text += "<td>" + tr("ascent: ") + "</td>";
-                IUnit::self().meter2elevation(info.ascend1, val, unit);
+                IUnit::self().meter2elevation(info.ascent1, val, unit);
                 text += "<td>"+ QString("%1%2").arg(val).arg(unit) + "</td>";
-                IUnit::self().meter2elevation(info.ascend2, val, unit);
+                IUnit::self().meter2elevation(info.ascent2, val, unit);
                 text += "<td>"+ QString("%1%2").arg(val).arg(unit) + "</td>";
-                IUnit::self().meter2elevation(info.ascend3, val, unit);
+                IUnit::self().meter2elevation(info.ascent3, val, unit);
                 text += "<td>"+ QString("%1%2").arg(val).arg(unit) + "</td>";
                 text += "</tr>";
 
                 text += "<tr>";
-                text += "<td>" + tr("descend: ") + "</td>";
-                IUnit::self().meter2elevation(info.descend1, val, unit);
+                text += "<td>" + tr("descent: ") + "</td>";
+                IUnit::self().meter2elevation(info.descent1, val, unit);
                 text += "<td>"+ QString("%1%2").arg(val).arg(unit) + "</td>";
-                IUnit::self().meter2elevation(info.descend2, val, unit);
+                IUnit::self().meter2elevation(info.descent2, val, unit);
                 text += "<td>"+ QString("%1%2").arg(val).arg(unit) + "</td>";
-                IUnit::self().meter2elevation(info.descend3, val, unit);
+                IUnit::self().meter2elevation(info.descent3, val, unit);
                 text += "<td>"+ QString("%1%2").arg(val).arg(unit) + "</td>";
                 text += "</tr>";
 
@@ -691,7 +675,7 @@ void CDetailsPrj::drawByTrack(QTextCursor& cursor, QList<CGisItemTrk *> &trks, Q
         }
 
         addIcon(table, eSym1, cnt, trk, printable);
-        table->cellAt(cnt,eInfo2).firstCursorPosition().insertHtml(trk->getInfo());
+        table->cellAt(cnt,eInfo2).firstCursorPosition().insertHtml(trk->getInfo(true, false));
 
         QTextTable * table1 = table->cellAt(cnt,eData2).lastCursorPosition().insertTable(1, 2, fmtTableInfo);
 
@@ -731,7 +715,7 @@ void CDetailsPrj::drawArea(QTextCursor& cursor, QList<CGisItemOvlArea *> &areas,
         PROGRESS(n++, return );
 
         addIcon(table, eSym1, cnt, area, printable);
-        table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(area->getInfo());
+        table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(area->getInfo(true, false));
         table->cellAt(cnt,eComment1).firstCursorPosition().insertHtml(IGisItem::createText(area->isReadOnly()||printable, area->getComment(), area->getDescription(), area->getLinks(), area->getKey().item));
         cnt++;
     }
@@ -761,7 +745,7 @@ void CDetailsPrj::drawRoute(QTextCursor& cursor, QList<CGisItemRte *> &rtes, CPr
         PROGRESS(n++, return );
 
         addIcon(table, eSym1, cnt, rte, printable);
-        table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(rte->getInfo());
+        table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(rte->getInfo(true, false));
         table->cellAt(cnt,eComment1).firstCursorPosition().insertHtml(IGisItem::createText(rte->isReadOnly()||printable, rte->getComment(), rte->getDescription(), rte->getLinks(), rte->getKey().item));
         cnt++;
     }
@@ -963,7 +947,7 @@ void CDetailsPrj::slotLock(bool on)
 void CDetailsPrj::slotSortMode(int idx)
 {
     comboSort->setEnabled(false);
-    prj.setSorting(IGisProject::sorting_e(idx));
+    prj.setSortingRoadbook(IGisProject::sorting_roadbook_e(idx));
     slotSetupGui();
 }
 
