@@ -212,13 +212,29 @@ void IGisProject::setLinks(const QList<IGisItem::link_t>& links)
     setChanged();
 }
 
-void IGisProject::setSorting(sorting_e s)
+void IGisProject::setSortingRoadbook(sorting_roadbook_e s)
 {
-    bool changed = s != sorting;
-    sorting = s;
+    changedRoadbookMode = (s != sortingRoadbook);
+    sortingRoadbook = s;
+    if(changedRoadbookMode)
+    {
+        setChanged();
+    }
+}
+
+void IGisProject::setSortingFolder(sorting_folder_e s)
+{
+    bool changed = (s != sortingFolder);
+    sortingFolder = s;
+    sortItems();
+
     if(changed)
     {
         setChanged();
+        if(dlgDetails != nullptr)
+        {
+            dlgDetails->updateData();
+        }
     }
 }
 
@@ -243,14 +259,23 @@ void IGisProject::updateItems()
         return;
     }
 
-
+    sortItems();
     updateItemCounters();
 
-    if(noCorrelation || (hashTrkWpt[0] == hashTrkWpt[1]) || (getItemCountByType(IGisItem::eTypeTrk) == 0))
+    if(noCorrelation)
     {
         return;
     }
 
+    if(!changedRoadbookMode)
+    {
+        if((hashTrkWpt[0] == hashTrkWpt[1]) || (getItemCountByType(IGisItem::eTypeTrk) == 0))
+        {
+            return;
+        }
+    }
+    changedRoadbookMode = false;
+
 
     quint32 total   = cntTrkPts * cntWpts;
     quint32 current = 0;
@@ -272,6 +297,11 @@ void IGisProject::updateItems()
             }
         }
     }
+
+    if(dlgDetails != nullptr)
+    {
+        dlgDetails->updateData();
+    }
 }
 
 bool IGisProject::save()
@@ -318,13 +348,12 @@ bool IGisProject::saveAs(QString fn, QString filter)
     if(filter == getFileDialogFilter())
     {
         filename = fn;
-        metadata.name.clear();
-        setupName(QFileInfo(fn).baseName());
+        setupName(QFileInfo(fn).completeBaseName());
     }
 
     if(filter == filedialogFilterGPX)
     {
-        res = CGpxProject::saveAs(fn, *this);
+        res = CGpxProject::saveAs(fn, *this, false);
     }
     else if(filter == filedialogFilterQMS)
     {
@@ -346,6 +375,34 @@ bool IGisProject::saveAs(QString fn, QString filter)
     return res;
 }
 
+bool IGisProject::saveAsStrictGpx11()
+{
+    SETTINGS;
+
+    QString fn;
+    QString path = cfg.value("Paths/lastGisPath", QDir::homePath()).toString();
+
+    // guess the correct extension:
+    // by default use the extension provided by the current format,
+    // otherwise use gpx
+    QString ext    = "gpx";
+    QString filter = IGisProject::filedialogFilterGPX;
+    path += "/" + getName() + "." + ext;
+
+    fn = QFileDialog::getSaveFileName(CMainWindow::getBestWidgetForParent(), tr("Save \"%1\" to...").arg(getName()), path, "Strict GPX V 1.1 (*.gpx *.GPX)", &filter);
+
+    if(fn.isEmpty())
+    {
+        return false;
+    }
+
+    bool res = CGpxProject::saveAs(fn, *this, true);
+
+    path = QFileInfo(fn).absolutePath();
+    cfg.setValue("Paths/lastGisPath", path);
+
+    return res;
+}
 
 void IGisProject::setupName(const QString &defaultName)
 {
@@ -826,8 +883,8 @@ void IGisProject::updateItemCounters()
     cntTrkPts = 0;
     cntWpts = 0;
     totalDistance = 0;
-    totalAscend = 0;
-    totalDescend = 0;
+    totalAscent = 0;
+    totalDescent = 0;
     totalElapsedSeconds = 0;
     totalElapsedSecondsMoving = 0;
 
@@ -851,8 +908,8 @@ void IGisProject::updateItemCounters()
         {
             cntTrkPts       += trk->getNumberOfVisiblePoints();
             totalDistance   += trk->getTotalDistance();
-            totalAscend     += trk->getTotalAscend();
-            totalDescend    += trk->getTotalDescend();
+            totalAscent     += trk->getTotalAscent();
+            totalDescent    += trk->getTotalDescent();
             totalElapsedSeconds += trk->getTotalElapsedSeconds();
             totalElapsedSecondsMoving += trk->getTotalElapsedSecondsMoving();
             stream << trk->getHash();
@@ -902,3 +959,92 @@ void IGisProject::updateDecoration()
 
     setText(CGisListWks::eColumnDecoration, saved ? "" : "*");
 }
+
+void IGisProject::sortItems()
+{
+    QList<IGisItem*> trks;
+    QList<IGisItem*> rtes;
+    QList<IGisItem*> wpts;
+    QList<IGisItem*> ovls;
+
+    QList<QTreeWidgetItem*> items = takeChildren();
+    for(QTreeWidgetItem* item : items)
+    {
+        CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(item);
+        if(trk != nullptr)
+        {
+            trks << trk;
+            continue;
+        }
+
+        CGisItemRte * rte = dynamic_cast<CGisItemRte*>(item);
+        if(rte != nullptr)
+        {
+            rtes << rte;
+            continue;
+        }
+
+        CGisItemWpt * wpt = dynamic_cast<CGisItemWpt*>(item);
+        if(wpt != nullptr)
+        {
+            wpts << wpt;
+            continue;
+        }
+
+        CGisItemOvlArea * ovl = dynamic_cast<CGisItemOvlArea*>(item);
+        if(ovl != nullptr)
+        {
+            ovls << ovl;
+            continue;
+        }
+    }
+
+    sortItems(trks);
+    sortItems(rtes);
+    sortItems(wpts);
+    sortItems(ovls);
+
+    items.clear();
+    for(IGisItem * item : trks)
+    {
+        items << item;
+    }
+    for(IGisItem * item : rtes)
+    {
+        items << item;
+    }
+    for(IGisItem * item : wpts)
+    {
+        items << item;
+    }
+    for(IGisItem * item : ovls)
+    {
+        items << item;
+    }
+
+    addChildren(items);
+}
+
+bool sortByName(IGisItem * item1, IGisItem * item2)
+{
+    return item1->getName() < item2->getName();
+}
+
+bool sortByTime(IGisItem * item1, IGisItem * item2)
+{
+    return item1->getTimestamp() < item2->getTimestamp();
+}
+
+void IGisProject::sortItems(QList<IGisItem *> &items) const
+{
+    switch(sortingFolder)
+    {
+    case IGisProject::eSortFolderName:
+        qSort(items.begin(), items.end(), &sortByName);
+        break;
+
+    case IGisProject::eSortFolderTime:
+        qSort(items.begin(), items.end(), &sortByTime);
+        break;
+    }
+}
