@@ -47,12 +47,18 @@ public:
         , eTypeFit
     };
 
-    enum sorting_e
+    enum sorting_roadbook_e
     {
-        eSortNone
-        , eSortTime
-        , eSortTrackWithDouble
-        , eSortTrackWithoutDouble
+        eSortRoadbookNone
+        , eSortRoadbookTrackWithDouble
+        , eSortRoadbookTrackWithoutDouble
+    };
+
+    enum sorting_folder_e
+    {
+        eSortFolderTime
+        ,eSortFolderName
+        ,eSortFolderSymbol
     };
 
     struct person_t
@@ -148,6 +154,12 @@ public:
      */
     bool saveAs(QString fn = QString(), QString filter = QString());
 
+    /**
+       @brief Save as strict GPX V 1.1 without any extensions and HTML
+       @return True on success
+     */
+    bool saveAsStrictGpx11();
+
     virtual void setFilename(const QString& fn)
     {
         filename = fn;
@@ -222,9 +234,14 @@ public:
        @brief Get the sorting mode
        @return One of sorting_e
      */
-    sorting_e getSorting() const
+    sorting_roadbook_e getSortingRoadbook() const
     {
-        return sorting;
+        return sortingRoadbook;
+    }
+
+    sorting_folder_e getSortingFolder() const
+    {
+        return sortingFolder;
     }
 
     void setName(const QString& str);
@@ -237,13 +254,22 @@ public:
     void setChanged();
 
     /**
-       @brief Set the sorting mode_t
+       @brief Set the sorting mode for the roadbook in the details dialog
 
        This will mark the project as changed.
 
        @param s the mode
      */
-    void setSorting(sorting_e s);
+    void setSortingRoadbook(sorting_roadbook_e s);
+
+    /**
+       @brief Set the sorting mode for workspace folder
+
+       This will mark the project as changed.
+
+       @param s the mode
+     */
+    void setSortingFolder(sorting_folder_e s);
 
     /**
        @brief Get a short metadata summary
@@ -280,13 +306,13 @@ public:
     {
         return totalDistance;
     }
-    qreal getTotalAscend() const
+    qreal getTotalAscent() const
     {
-        return totalAscend;
+        return totalAscent;
     }
-    qreal getTotalDescend() const
+    qreal getTotalDescent() const
     {
-        return totalDescend;
+        return totalDescent;
     }
     qreal getTotalElapsedSeconds() const
     {
@@ -399,7 +425,7 @@ public:
        @param doc
        @return
      */
-    QDomNode writeMetadata(QDomDocument& doc);
+    QDomNode writeMetadata(QDomDocument& doc, bool strictGpx11);
 
     /**
        @brief Mount volume the project's file is stored at
@@ -451,6 +477,8 @@ protected:
     void updateItems();
     void updateItemCounters();
     void updateDecoration();
+    void sortItems();
+    void sortItems(QList<IGisItem*>& items) const;
 
     /**
        @brief Converts a string with HTML tags to a string without HTML depending on the device
@@ -482,11 +510,13 @@ protected:
     bool valid         = false;
     bool noUpdate      = false;
     bool noCorrelation = false;
+    bool changedRoadbookMode = false;
 
     metadata_t metadata;
     QString nameSuffix;
 
-    sorting_e sorting = eSortNone;
+    sorting_roadbook_e sortingRoadbook  = eSortRoadbookNone;
+    sorting_folder_e sortingFolder    = eSortFolderTime;
 
     qint32 cntItemsByType[IGisItem::eTypeMax];
 
@@ -494,8 +524,8 @@ protected:
     qint32 cntWpts                   = 0;
 
     qreal totalDistance             = 0;
-    qreal totalAscend               = 0;
-    qreal totalDescend              = 0;
+    qreal totalAscent               = 0;
+    qreal totalDescent              = 0;
     quint32 totalElapsedSeconds       = 0;
     quint32 totalElapsedSecondsMoving = 0;
 
