@@ -41,7 +41,7 @@
 #define VER_GC_T        quint8(1)
 #define VER_GCLOG_T     quint8(1)
 #define VER_IMAGE       quint8(1)
-#define VER_PROJECT     quint8(4)
+#define VER_PROJECT     quint8(5)
 #define VER_COPYRIGHT   quint8(1)
 #define VER_PERSON      quint8(1)
 #define VER_HIST        quint8(1)
@@ -332,20 +332,20 @@ QDataStream& operator>>(QDataStream& stream, CGisItemWpt::image_t& image)
     return stream;
 }
 
-QDataStream& operator<<(QDataStream& stream, const CGisItemTrk::trkseg_t& seg)
+QDataStream& operator<<(QDataStream& stream, const CTrackData::trkseg_t& seg)
 {
     stream << VER_TRKSEG << seg.pts;
     return stream;
 }
 
-QDataStream& operator>>(QDataStream& stream, CGisItemTrk::trkseg_t& seg)
+QDataStream& operator>>(QDataStream& stream, CTrackData::trkseg_t& seg)
 {
     quint8 version;
     stream >> version >> seg.pts;
     return stream;
 }
 
-QDataStream& operator<<(QDataStream& stream, const CGisItemTrk::trkpt_t& pt)
+QDataStream& operator<<(QDataStream& stream, const CTrackData::trkpt_t& pt)
 {
     stream << VER_TRKPT << pt.flags;
     stream << (const IGisItem::wpt_t&)pt;
@@ -353,7 +353,7 @@ QDataStream& operator<<(QDataStream& stream, const CGisItemTrk::trkpt_t& pt)
     return stream;
 }
 
-QDataStream& operator>>(QDataStream& stream, CGisItemTrk::trkpt_t& pt)
+QDataStream& operator>>(QDataStream& stream, CTrackData::trkpt_t& pt)
 {
     quint8 version;
     stream >> version >> pt.flags;
@@ -604,7 +604,7 @@ QDataStream& CGisItemTrk::operator<<(QDataStream& stream)
     deriveSecondaryData();
     setColor(str2color(trk.color));
     setText(   CGisListWks::eColumnName, getName());
-    setToolTip(CGisListWks::eColumnName, getInfo());
+    setToolTip(CGisListWks::eColumnName, getInfo(true, false));
     return stream;
 }
 
@@ -646,7 +646,7 @@ QDataStream& CGisItemWpt::operator<<(QDataStream& stream)
 
     setIcon();
     setText   (CGisListWks::eColumnName, getName());
-    setToolTip(CGisListWks::eColumnName, getInfo());
+    setToolTip(CGisListWks::eColumnName, getInfo(true, false));
 
     return stream;
 }
@@ -717,15 +717,15 @@ QDataStream& CGisItemRte::operator<<(QDataStream& stream)
     }
     if(version > 2)
     {
-        in >> rte.ascend;
-        in >> rte.descend;
+        in >> rte.ascent;
+        in >> rte.descent;
     }
 
 
     setSymbol();
     deriveSecondaryData();
     setText   (CGisListWks::eColumnName, getName());
-    setToolTip(CGisListWks::eColumnName, getInfo());
+    setToolTip(CGisListWks::eColumnName, getInfo(true, false));
 
     return stream;
 }
@@ -751,8 +751,8 @@ QDataStream& CGisItemRte::operator>>(QDataStream& stream) const
     out << rte.lastRoutedTime;
     out << rte.totalDistance;
     out << rte.totalTime;
-    out << rte.ascend;
-    out << rte.descend;
+    out << rte.ascent;
+    out << rte.descent;
 
     stream.writeRawData(MAGIC_RTE, MAGIC_SIZE);
     stream << VER_RTE;
@@ -805,7 +805,7 @@ QDataStream& CGisItemOvlArea::operator<<(QDataStream& stream)
 
     setColor(str2color(area.color));
     setText   (CGisListWks::eColumnName, getName());
-    setToolTip(CGisListWks::eColumnName, getInfo());
+    setToolTip(CGisListWks::eColumnName, getInfo(true, false));
 
     return stream;
 }
@@ -857,7 +857,15 @@ QDataStream& IGisProject::operator<<(QDataStream& stream)
     blockUpdateItems(true);
 
     stream >> version;
-    stream >> filename;
+    if(filename.isEmpty())
+    {
+        stream >> filename;
+    }
+    else
+    {
+        QString tmp;
+        stream >> tmp;
+    }
     stream >> metadata.name;
     stream >> metadata.desc;
     stream >> metadata.author;
@@ -874,7 +882,7 @@ QDataStream& IGisProject::operator<<(QDataStream& stream)
     {
         qint32 tmp;
         stream >> tmp;
-        sorting = (sorting_e)tmp;
+        sortingRoadbook = (sorting_roadbook_e)tmp;
     }
     if(version > 3)
     {
@@ -883,6 +891,13 @@ QDataStream& IGisProject::operator<<(QDataStream& stream)
         noCorrelation = tmp != 0;
     }
 
+    if(version > 4)
+    {
+        qint32 tmp;
+        stream >> tmp;
+        sortingFolder = (sorting_folder_e)tmp;
+    }
+
     while(!stream.atEnd())
     {
         QString lastDatabaseHash;
@@ -932,6 +947,8 @@ QDataStream& IGisProject::operator<<(QDataStream& stream)
         }
     }
 
+    sortItems();
+
     blockUpdateItems(false);
     return stream;
 }
@@ -951,8 +968,9 @@ QDataStream& IGisProject::operator>>(QDataStream& stream) const
     stream << metadata.keywords;
     stream << metadata.bounds;
     stream << key;
-    stream << qint32(sorting);
+    stream << qint32(sortingRoadbook);
     stream << qint8(noCorrelation);
+    stream << qint32(sortingFolder);
 
     for(int i = 0; i < childCount(); i++)
     {
@@ -1043,7 +1061,7 @@ QDataStream& CDBProject::operator<<(QDataStream& stream)
     {
         qint32 tmp;
         stream >> tmp;
-        sorting = (sorting_e)tmp;
+        sortingRoadbook = (sorting_roadbook_e)tmp;
     }
     if(version > 3)
     {
@@ -1051,6 +1069,12 @@ QDataStream& CDBProject::operator<<(QDataStream& stream)
         stream >> tmp;
         noCorrelation = tmp != 0;
     }
+    if(version > 4)
+    {
+        qint32 tmp;
+        stream >> tmp;
+        sortingFolder = (sorting_folder_e)tmp;
+    }
 
     return stream;
 }
@@ -1070,8 +1094,9 @@ QDataStream& CDBProject::operator>>(QDataStream& stream) const
     stream << metadata.keywords;
     stream << metadata.bounds;
     stream << key;
-    stream << qint32(sorting);
+    stream << qint32(sortingRoadbook);
     stream << qint8(noCorrelation);
+    stream << qint32(sortingFolder);
 
     return stream;
 }
