@@ -191,15 +191,15 @@ void CGisItemRte::setElevation(qreal ele, subpt_t& subpt, qreal& lastEle)
     {
         qreal delta   = subpt.ele - lastEle;
 
-        if(qAbs(delta) > ASCEND_THRESHOLD)
+        if(qAbs(delta) > ASCENT_THRESHOLD)
         {
             if(delta > 0)
             {
-                rte.ascend  += delta;
+                rte.ascent  += delta;
             }
             else
             {
-                rte.descend -= delta;
+                rte.descent -= delta;
             }
             lastEle = subpt.ele;
         }
@@ -251,8 +251,8 @@ void CGisItemRte::deriveSecondaryData()
     {
         qreal lastEle = NOFLOAT;
         int i = 0;
-        rte.descend = 0;
-        rte.ascend = 0;
+        rte.descent = 0;
+        rte.ascent = 0;
 
         for(rtept_t &rtept : rte.pts)
         {
@@ -330,9 +330,9 @@ void CGisItemRte::setLinks(const QList<link_t>& links)
 
 
 
-QString CGisItemRte::getInfo(bool showName) const
+QString CGisItemRte::getInfo(bool showName, bool showFullText) const
 {
-    QString val1, unit1, val2, unit2;
+    QString val1, unit1;
     QString str = "<div>";
 
     if(showName)
@@ -361,12 +361,12 @@ QString CGisItemRte::getInfo(bool showName) const
         str += tr("Time: -");
     }
 
-    if((rte.ascend != NOFLOAT) && (rte.descend != NOFLOAT))
+    if((rte.ascent != NOFLOAT) && (rte.descent != NOFLOAT))
     {
         str += "<br/>\n";
         QString val1, val2, unit1, unit2;
-        IUnit::self().meter2elevation(rte.ascend,  val1, unit1);
-        IUnit::self().meter2elevation(rte.descend, val2, unit2);
+        IUnit::self().meter2elevation(rte.ascent,  val1, unit1);
+        IUnit::self().meter2elevation(rte.descent, val2, unit2);
 
         str += tr("%1%2 %3, %4%5 %6").arg(QChar(0x2197)).arg(val1).arg(unit1).arg(QChar(0x2198)).arg(val2).arg(unit2);
     }
@@ -378,7 +378,44 @@ QString CGisItemRte::getInfo(bool showName) const
         str += "<br/>\n";
         str += tr("with %1").arg(rte.lastRoutedWith);
     }
-    return str;
+
+    QString desc = removeHtml(rte.desc).simplified();
+    if(desc.count())
+    {
+        if(!str.isEmpty())
+        {
+            str += "<br/>\n";
+        }
+
+        if(showFullText || (desc.count() < 300))
+        {
+            str += desc;
+        }
+        else
+        {
+            str += desc.left(297) + "...";
+        }
+    }
+
+    QString cmt = removeHtml(rte.cmt).simplified();
+    if((cmt != desc) && cmt.count())
+    {
+        if(!str.isEmpty())
+        {
+            str += "<br/>\n";
+        }
+
+        if(showFullText || cmt.count() < 300)
+        {
+            str += cmt;
+        }
+        else
+        {
+            str += cmt.left(297) + "...";
+        }
+    }
+
+    return str + "</div>";
 }
 
 IScrOpt * CGisItemRte::getScreenOptions(const QPoint& origin, IMouse * mouse)
@@ -545,6 +582,10 @@ void CGisItemRte::drawItem(QPainter& p, const QRectF& viewport, CGisDraw * gis)
     }
 
     QDateTime startTime = rte.pts.first().fakeSubpt.time;
+    if(!startTime.isValid() && !rte.pts.isEmpty() && !rte.pts.first().subpts.isEmpty())
+    {
+        startTime = rte.pts.first().subpts.first().time;
+    }
 
     if(hasUserFocus() && mouseMoveFocus && mouseMoveFocus->lon != NOFLOAT && mouseMoveFocus->lat != NOFLOAT)
     {
@@ -654,6 +695,7 @@ void CGisItemRte::readRouteDataFromGisLine(const SGisLine &l)
         rtept.lon = pt.coord.x() * RAD_TO_DEG;
         rtept.lat = pt.coord.y() * RAD_TO_DEG;
         rtept.ele = pt.ele;
+        rtept.name = pt.name;
     }
 
     if(doAutoRouting)
