@@ -101,8 +101,8 @@ public:
 
         qreal totalDistance = NOFLOAT;
         quint32 totalTime = 0;
-        qreal ascend  = NOFLOAT;
-        qreal descend = NOFLOAT;
+        qreal ascent  = NOFLOAT;
+        qreal descent = NOFLOAT;
     };
 
     CGisItemRte(const QDomNode &xml, IGisProject *parent);
@@ -124,14 +124,14 @@ public:
         return rte.name.isEmpty() ? noName : rte.name;
     }
 
-    QString getInfo(bool showName = true) const override;
+    QString getInfo(bool showName, bool showFullText) const override;
     IScrOpt * getScreenOptions(const QPoint &origin, IMouse * mouse) override;
     QPointF getPointCloseBy(const QPoint& screenPos) override;
     void drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>& blockedAreas, CGisDraw * gis) override;
     void drawItem(QPainter& p, const QRectF& viewport, CGisDraw * gis) override;
     void drawLabel(QPainter& p, const QPolygonF& viewport, QList<QRectF>& blockedAreas, const QFontMetricsF& fm, CGisDraw * gis) override;
     void drawHighlight(QPainter& p) override;
-    void save(QDomNode& gpx) override;
+    void save(QDomNode& gpx, bool strictGpx11) override;
     bool isCloseTo(const QPointF& pos) override;
     bool isWithin(const QRectF& area, selflags_t flags) override;
     /**
@@ -191,6 +191,12 @@ public:
         return rte;
     }
 
+    QDateTime getTimestamp() const override
+    {
+        return QDateTime();
+    }
+
+
     void setName(const QString& str);
     void setComment(const QString& str)       override;
     void setDescription(const QString& str)   override;
