@@ -22,9 +22,9 @@
 #include "gis/rte/CGisItemRte.h"
 #include "gis/rte/router/CRouterRoutino.h"
 #include "gis/rte/router/CRouterRoutinoPathSetup.h"
-#include "helpers/CAppSetup.h"
 #include "helpers/CProgressDialog.h"
 #include "helpers/CSettings.h"
+#include "setup/IAppSetup.h"
 #include <QtWidgets>
 #include <proj_api.h>
 #include <routino.h>
@@ -60,7 +60,7 @@ CRouterRoutino::CRouterRoutino(QWidget *parent)
     comboMode->addItem(tr("Quickest"));
 
     int res = 0;
-    CAppSetup *setup = CAppSetup::getPlattformInstance();
+    IAppSetup *setup = IAppSetup::getPlatformInstance();
     res = Routino_ParseXMLProfiles(setup->routinoPath("profiles.xml").toUtf8());
     if(res)
     {
@@ -75,24 +75,24 @@ CRouterRoutino::CRouterRoutino(QWidget *parent)
         return;
     }
 
-    comboProfile->addItem(tr("Foot"), "foot");
-    comboProfile->addItem(tr("Horse"), "horse");
+    comboProfile->addItem(tr("Foot"),       "foot");
+    comboProfile->addItem(tr("Horse"),      "horse");
     comboProfile->addItem(tr("Wheelchair"), "wheelchair");
-    comboProfile->addItem(tr("Bicycle"), "bicycle");
-    comboProfile->addItem(tr("Moped"), "moped");
+    comboProfile->addItem(tr("Bicycle"),    "bicycle");
+    comboProfile->addItem(tr("Moped"),      "moped");
     comboProfile->addItem(tr("Motorcycle"), "motorcycle");
-    comboProfile->addItem(tr("Motorcar"), "motorcar");
-    comboProfile->addItem(tr("Goods"), "goods");
+    comboProfile->addItem(tr("Motorcar"),   "motorcar");
+    comboProfile->addItem(tr("Goods"),      "goods");
 
-    comboLanguage->addItem(tr("English"), "en");
-    comboLanguage->addItem(tr("German"), "de");
-    comboLanguage->addItem(tr("French"), "fr");
+    comboLanguage->addItem(tr("English"),   "en");
+    comboLanguage->addItem(tr("German"),    "de");
+    comboLanguage->addItem(tr("French"),    "fr");
     comboLanguage->addItem(tr("Hungarian"), "hu");
-    comboLanguage->addItem(tr("Dutch"), "nl");
-    comboLanguage->addItem(tr("Russian"), "ru");
-    comboLanguage->addItem(tr("Polish"), "pl");
+    comboLanguage->addItem(tr("Dutch"),     "nl");
+    comboLanguage->addItem(tr("Russian"),   "ru");
+    comboLanguage->addItem(tr("Polish"),    "pl");
 
-    connect(toolSetupPaths, SIGNAL(clicked()), this, SLOT(slotSetupPaths()));
+    connect(toolSetupPaths, &QToolButton::clicked, this, &CRouterRoutino::slotSetupPaths);
 
     SETTINGS;
     dbPaths = cfg.value("Route/routino/paths", dbPaths).toStringList();
@@ -158,7 +158,7 @@ QString CRouterRoutino::xlateRoutinoError(int err)
         return tr("The requested translation language does not exist in the loaded XML file.");
 
     case ROUTINO_ERROR_NO_NEARBY_HIGHWAY:
-        return tr("There is no highway near the coordinates to place a waypoint.");
+        return tr("In the routing database there is no highway near the coordinates to place a waypoint.");
 
     case ROUTINO_ERROR_PROFILE_DATABASE_ERR:
         return tr("The profile and database do not work together.");
@@ -216,10 +216,10 @@ void CRouterRoutino::buildDatabaseList()
     QRegExp re("(.*)-segments.mem");
     freeDatabaseList();
 
-    foreach(const QString &path, dbPaths)
+    for(const QString &path : dbPaths)
     {
         QDir dir(path);
-        foreach(const QString &filename, dir.entryList(QStringList("*segments.mem"), QDir::Files|QDir::Readable, QDir::Name))
+        for(const QString &filename : dir.entryList(QStringList("*segments.mem"), QDir::Files|QDir::Readable, QDir::Name))
         {
             QString prefix;
             if(re.exactMatch(filename))
@@ -231,15 +231,17 @@ void CRouterRoutino::buildDatabaseList()
                 continue;
             }
 
-#ifdef OS_WIN
+#ifdef Q_OS_WIN
             QFileInfo fi(dir.absoluteFilePath(filename));
             if(fi.size() > 0x0FFFFFFFFLL)
             {
                 QMessageBox::warning(this, tr("Warning..."), tr("%1: Due to limitations in the Windows POSIX API Routino can't handle files larger than 4GB.").arg(prefix), QMessageBox::Ok);
                 continue;
             }
-#endif
+            Routino_Database * data = Routino_LoadDatabase(dir.absolutePath().toLocal8Bit(), prefix.toLocal8Bit());
+#else
             Routino_Database * data = Routino_LoadDatabase(dir.absolutePath().toUtf8(), prefix.toUtf8());
+#endif
             if(data)
             {
                 comboDatabase->addItem(prefix.replace("_", " "), quint64(data));
@@ -264,16 +266,10 @@ void CRouterRoutino::freeDatabaseList()
 
 void CRouterRoutino::updateHelpText()
 {
-    if(comboDatabase->count() != 0)
-    {
-        frameHelp->hide();
-        comboDatabase->setEnabled(true);
-    }
-    else
-    {
-        frameHelp->show();
-        comboDatabase->setEnabled(false);
-    }
+    bool haveDB = (comboDatabase->count() != 0);
+
+    frameHelp->setVisible(!haveDB);
+    comboDatabase->setEnabled(haveDB);
 }
 
 void CRouterRoutino::calcRoute(const IGisItem::key_t& key)
@@ -288,22 +284,22 @@ void CRouterRoutino::calcRoute(const IGisItem::key_t& key)
         QTime time;
         time.start();
 
-        CGisItemRte * rte       = dynamic_cast<CGisItemRte*>(CGisWidget::self().getItemByKey(key));
-        if(rte == 0)
+        CGisItemRte * rte = dynamic_cast<CGisItemRte*>(CGisWidget::self().getItemByKey(key));
+        if(nullptr == rte)
         {
             throw QString();
         }
 
         Routino_Database * data = (Routino_Database*)comboDatabase->currentData(Qt::UserRole).toULongLong();
-        if(data == 0)
+        if(nullptr == data)
         {
             throw QString();
         }
 
         rte->reset();
 
-        QString strProfile      = comboProfile->currentData(Qt::UserRole).toString();
-        QString strLanguage     = comboLanguage->currentData(Qt::UserRole).toString();
+        QString strProfile  = comboProfile->currentData(Qt::UserRole).toString();
+        QString strLanguage = comboLanguage->currentData(Qt::UserRole).toString();
 
         Routino_Profile *profile         = Routino_GetProfile(strProfile.toUtf8());
         Routino_Translation *translation = Routino_GetTranslation(strLanguage.toUtf8());
@@ -328,11 +324,11 @@ void CRouterRoutino::calcRoute(const IGisItem::key_t& key)
         rte->getPolylineFromData(line);
 
         int idx = 0;
-        QVector<Routino_Waypoint*> waypoints(line.size(), 0);
-        foreach(const IGisLine::point_t &pt, line)
+        QVector<Routino_Waypoint*> waypoints(line.size(), nullptr);
+        for(const IGisLine::point_t &pt : line)
         {
             waypoints[idx] = Routino_FindWaypoint(data, profile, pt.coord.y()*RAD_TO_DEG, pt.coord.x()*RAD_TO_DEG);
-            if(waypoints[idx] == NULL)
+            if(waypoints[idx] == nullptr)
             {
                 throw xlateRoutinoError(Routino_errno);
             }
@@ -345,7 +341,7 @@ void CRouterRoutino::calcRoute(const IGisItem::key_t& key)
 
         delete progress;
 
-        if(route != NULL)
+        if(nullptr != route)
         {
             rte->setResult(route, getOptions() + tr("<br/>Calculation time: %1s").arg(time.elapsed()/1000.0, 0,'f',2));
             Routino_DeleteRoute(route);
@@ -386,7 +382,7 @@ int CRouterRoutino::calcRoute(const QPointF& p1, const QPointF& p2, QPolygonF& c
     try
     {
         Routino_Database * data = (Routino_Database*)comboDatabase->currentData(Qt::UserRole).toULongLong();
-        if(data == 0)
+        if(nullptr == data)
         {
             throw QString();
         }
@@ -415,13 +411,13 @@ int CRouterRoutino::calcRoute(const QPointF& p1, const QPointF& p2, QPolygonF& c
 
         Routino_Waypoint* waypoints[2] = {0};
         waypoints[0] = Routino_FindWaypoint(data, profile, p1.y()*RAD_TO_DEG, p1.x()*RAD_TO_DEG);
-        if(waypoints[0] == NULL)
+        if(waypoints[0] == nullptr)
         {
             throw xlateRoutinoError(Routino_errno);
         }
 
         waypoints[1] = Routino_FindWaypoint(data, profile, p2.y()*RAD_TO_DEG, p2.x()*RAD_TO_DEG);
-        if(waypoints[1] == NULL)
+        if(waypoints[1] == nullptr)
         {
             throw xlateRoutinoError(Routino_errno);
         }
@@ -432,7 +428,7 @@ int CRouterRoutino::calcRoute(const QPointF& p1, const QPointF& p2, QPolygonF& c
 
         delete progress;
 
-        if(route != NULL)
+        if(route != nullptr)
         {
             Routino_Output * next = route;
             while(next)
@@ -459,11 +455,13 @@ int CRouterRoutino::calcRoute(const QPointF& p1, const QPointF& p2, QPolygonF& c
     }
     catch(const QString& msg)
     {
+        coords.clear();
+
         if(!msg.isEmpty())
         {
-            QMessageBox::critical(this, "Routino...", msg, QMessageBox::Abort);
+            mutex.unlock();
+            throw msg;
         }
-        coords.clear();
     }
 
     mutex.unlock();
