@@ -19,7 +19,7 @@
 #ifndef CSEARCHGOOGLE_H
 #define CSEARCHGOOGLE_H
 
-#include <gis/prj/IGisProject.h>
+#include "gis/prj/IGisProject.h"
 
 #include <QNetworkAccessManager>
 #include <QObject>
@@ -34,15 +34,6 @@ public:
     CSearchGoogle(CGisListWks * parent);
     virtual ~CSearchGoogle();
 
-    bool save()
-    {
-        return false;
-    }
-    bool saveAs()
-    {
-        return false;
-    }
-
 private slots:
     void slotChangeSymbol();
     void slotStartSearch();
