@@ -21,6 +21,8 @@
 
 #include <QCoreApplication>
 #include <QIcon>
+#include <QMap>
+#include <QMenu>
 #include <QPointer>
 #include <QVector>
 class CGisItemTrk;
@@ -36,22 +38,22 @@ public:
 
     struct activity_summary_t
     {
-        activity_summary_t() : distance(0), ascend(0), descend(0), ellapsedSeconds(0), ellapsedSecondsMoving(0)
+        activity_summary_t() : distance(0), ascent(0), descent(0), ellapsedSeconds(0), ellapsedSecondsMoving(0)
         {
         }
 
         void reset()
         {
             distance = 0;
-            ascend = 0;
-            descend = 0;
+            ascent = 0;
+            descent = 0;
             ellapsedSeconds = 0;
             ellapsedSecondsMoving = 0;
         }
 
         qreal distance;
-        qreal ascend;
-        qreal descend;
+        qreal ascent;
+        qreal descent;
         qreal ellapsedSeconds;
         qreal ellapsedSecondsMoving;
     };
@@ -93,6 +95,10 @@ public:
         return allFlags;
     }
 
+    void getActivityNames(QStringList& names) const;
+
+    static quint32 selectActivity(QWidget *parent);
+
     /**
        @brief Convert internal summary to HTML table
        @param str   string to receive HTML
@@ -104,13 +110,14 @@ public:
        @param summary  The array of summaries
        @param str   string to receive HTML
      */
-    static void printSummary(const QVector<activity_summary_t> &summary, quint32 flags, QString& str);
+    static void printSummary(const QMap<quint32, activity_summary_t> &summary, quint32 flags, QString& str);
+
 
     /**
        @brief Add internal summary to given array of summaries
        @param summary  an array of summaries to hold the sum
      */
-    void sumUp(QVector<activity_summary_t> &summary) const;
+    void sumUp(QMap<quint32, activity_summary_t> &summary) const;
 
 
     const QList<activity_range_t>& getActivityRanges() const
@@ -118,7 +125,7 @@ public:
         return activityRanges;
     }
 
-    static const desc_t* getActivityDescriptors()
+    static const QVector<desc_t>& getActivityDescriptors()
     {
         return actDescriptor;
     }
@@ -130,15 +137,13 @@ public:
 private:
     friend class CGisItemTrk;
     CActivityTrk(CGisItemTrk * trk);
-    static activity_summary_t& getSummary(QVector<activity_summary_t> &summary, quint32 flag);
-    static const activity_summary_t& getSummary(const QVector<activity_summary_t> &summary, quint32 flag);
 
-    static desc_t actDescriptor[];
+    static QVector<desc_t> actDescriptor;
 
     CGisItemTrk * trk;
     quint32 allFlags;
     QList<activity_range_t> activityRanges;
-    QVector<activity_summary_t>  activitySummary;
+    QMap<quint32, activity_summary_t> activitySummary;
 };
 
 #endif //CACTIVITYTRK_H
