@@ -22,6 +22,7 @@
 #include "gis/trk/filter/CFilterDelete.h"
 #include "gis/trk/filter/CFilterDeleteExtension.h"
 #include "gis/trk/filter/CFilterDouglasPeuker.h"
+#include "gis/trk/filter/CFilterInterpolateElevation.h"
 #include "gis/trk/filter/CFilterInvalid.h"
 #include "gis/trk/filter/CFilterMedian.h"
 #include "gis/trk/filter/CFilterNewDate.h"
@@ -31,6 +32,7 @@
 #include "gis/trk/filter/CFilterReset.h"
 #include "gis/trk/filter/CFilterSpeed.h"
 #include "gis/trk/filter/CFilterSplitSegment.h"
+#include "gis/trk/filter/CFilterSubPt2Pt.h"
 #include "helpers/CLinksDialog.h"
 #include "helpers/CSettings.h"
 #include "helpers/Signals.h"
@@ -90,24 +92,6 @@ CDetailsTrk::CDetailsTrk(CGisItemTrk& trk, QWidget *parent)
 
     widgetColorActivity->setTrack(&trk);
 
-    const CActivityTrk::desc_t* actDesc = CActivityTrk::getActivityDescriptors();
-    for(int i = 0; !actDesc[i].name.isEmpty(); ++i)
-    {
-        const CActivityTrk::desc_t& desc = actDesc[i];
-        QCheckBox * check = new QCheckBox(this);
-        check->setText(desc.name);
-        check->setIcon(QIcon(desc.iconLarge));
-        check->setProperty("flag",   desc.flag);
-        check->setProperty("name",   desc.name);
-        check->setProperty("symbol", desc.iconLarge);
-        check->setObjectName("check" + desc.objName);
-
-        connect(check, &QCheckBox::clicked, this, &CDetailsTrk::slotActivitySelected);
-
-        layoutActivities->addWidget(check, i%8, i>>3);
-    }
-    layoutActivities->addItem(new QSpacerItem(0,0,QSizePolicy::Maximum, QSizePolicy::MinimumExpanding),8,0);
-
     updateData();
 
     treeWidget->setTrack(&trk);
@@ -145,6 +129,9 @@ CDetailsTrk::CDetailsTrk(CGisItemTrk& trk, QWidget *parent)
     connect(toolLock,         &QToolButton::toggled,               this, &CDetailsTrk::slotChangeReadOnlyMode);
     connect(textCmtDesc,      &QTextBrowser::anchorClicked,        this, &CDetailsTrk::slotLinkActivated);
 
+    connect(pushSetActivities,    &QPushButton::clicked, this, &CDetailsTrk::slotSetActivities);
+    connect(pushRemoveActivities, &QPushButton::clicked, this, &CDetailsTrk::slotRemoveActivities);
+
     connect(lineName,         &QLineEdit::textEdited,              this, &CDetailsTrk::slotNameChanged);
     connect(lineName,         &QLineEdit::editingFinished,         this, &CDetailsTrk::slotNameChangeFinished);
 
@@ -180,17 +167,14 @@ CDetailsTrk::CDetailsTrk(CGisItemTrk& trk, QWidget *parent)
     addFilterGroup<CFilterDouglasPeuker, CFilterInvalid, CFilterReset, CFilterDelete>
         (treeFilter, trk, tr("Reduce visible track points"), "://icons/48x48/PointHide.png");
 
-    addFilterGroup<CFilterMedian, CFilterReplaceElevation, CFilterOffsetElevation>
+    addFilterGroup<CFilterMedian, CFilterInterpolateElevation, CFilterReplaceElevation, CFilterOffsetElevation>
         (treeFilter, trk, tr("Change elevation of track points"), "://icons/48x48/SetEle.png");
 
     addFilterGroup<CFilterNewDate, CFilterObscureDate, CFilterSpeed>
         (treeFilter, trk, tr("Change timestamp of track points"), "://icons/48x48/Time.png");
 
-    addFilterGroup<CFilterDeleteExtension>
-        (treeFilter, trk, tr("Modify track points' extensions"), "://icons/48x48/FilterModifyExtension.png");
-
-    addFilterGroup<CFilterSplitSegment>
-        (treeFilter, trk, tr("Cut track into pieces"), "://icons/48x48/TrkCut.png");
+    addFilterGroup<CFilterDeleteExtension, CFilterSplitSegment, CFilterSubPt2Pt>
+        (treeFilter, trk, tr("Miscellaneous"), "://icons/48x48/CSrcUnknown.png");
 
 
     slotShowPlots();
@@ -200,11 +184,11 @@ CDetailsTrk::~CDetailsTrk()
 {
     SETTINGS;
     cfg.beginGroup("TrackDetails");
-    cfg.setValue("showGraph1",          checkGraph1->isChecked());
-    cfg.setValue("showGraph2",          checkGraph2->isChecked());
-    cfg.setValue("showGraph3",          checkGraph3->isChecked());
-    cfg.setValue("splitterSizes",       splitter->saveState());
-    cfg.setValue("visibleTab",          tabWidget->currentIndex());
+    cfg.setValue("showGraph1",    checkGraph1->isChecked());
+    cfg.setValue("showGraph2",    checkGraph2->isChecked());
+    cfg.setValue("showGraph3",    checkGraph3->isChecked());
+    cfg.setValue("splitterSizes", splitter->saveState());
+    cfg.setValue("visibleTab",    tabWidget->currentIndex());
     cfg.endGroup();
 
     saveGraphSource(comboGraph2, 2);
@@ -321,6 +305,10 @@ void CDetailsTrk::setupStyleLimits(CLimit& limit, QToolButton *toolLimitAuto, QT
 void CDetailsTrk::loadGraphSource(QComboBox * comboBox, qint32 n, const QString cfgDefault)
 {
     const CPropertyTrk * p = trk.getPropertyHandler();
+    if(p == nullptr)
+    {
+        return;
+    }
 
     comboBox->blockSignals(true);
     p->fillComboBox(comboBox);
@@ -366,7 +354,7 @@ void CDetailsTrk::updateData()
 
     labelTainted->setVisible(trk.isTainted());
 
-    labelInfo->setText(trk.getInfo(false));
+    labelInfo->setText(trk.getInfo(false, false));
     comboColor->setCurrentIndex(trk.getColorIdx());
     toolLock->setChecked(isReadOnly);
 
@@ -378,24 +366,12 @@ void CDetailsTrk::updateData()
     textCmtDesc->moveCursor (QTextCursor::Start);
     textCmtDesc->ensureCursorVisible();
 
-    quint32 flags = trk.getActivities().getAllFlags();
-
-    const CActivityTrk::desc_t* actDesc = CActivityTrk::getActivityDescriptors();
-    for(int i = 0; !actDesc[i].objName.isEmpty(); ++i)
-    {
-        const CActivityTrk::desc_t& desc = actDesc[i];
-        QCheckBox * check = findChild<QCheckBox*>("check" + desc.objName);
-        if(nullptr != check)
-        {
-            check->setChecked((flags & desc.flag) == desc.flag);
-        }
-    }
-
     QString str;
     trk.getActivities().printSummary(str);
     labelActivityInfo->setText(str);
 
-    bool hasActivity = 0 != (flags & CGisItemTrk::trkpt_t::eActMask);
+    quint32 flags = trk.getActivities().getAllFlags();
+    bool hasActivity = 0 != (flags & CTrackData::trkpt_t::eActMask);
     labelActivityHelp->setVisible(!hasActivity);
     labelActivityInfo->setVisible(hasActivity);
 
@@ -469,6 +445,7 @@ void CDetailsTrk::updateData()
         widgetColorLabel->setUnit(ext.unit);
     }
 
+    widgetColorActivity->updateData();
     widgetColorActivity->setVisible(enabledActivity);
     widgetColorActivity->setEnabled(enabledActivity);
 
@@ -489,7 +466,7 @@ void CDetailsTrk::updateData()
     CCanvas::restoreOverrideCursor("CDetailsTrk::updateData");
 }
 
-void CDetailsTrk::setMouseFocus(const CGisItemTrk::trkpt_t * pt)
+void CDetailsTrk::setMouseFocus(const CTrackData::trkpt_t * pt)
 {
     if(nullptr != pt)
     {
@@ -504,12 +481,12 @@ void CDetailsTrk::setMouseFocus(const CGisItemTrk::trkpt_t * pt)
     }
 }
 
-void CDetailsTrk::setMouseRangeFocus(const CGisItemTrk::trkpt_t *pt1, const CGisItemTrk::trkpt_t *pt2)
+void CDetailsTrk::setMouseRangeFocus(const CTrackData::trkpt_t *pt1, const CTrackData::trkpt_t *pt2)
 {
     labelInfoRange->setText( (pt1 && pt2) ? trk.getInfoRange(*pt1, *pt2) : "-\n-" );
 }
 
-void CDetailsTrk::setMouseClickFocus(const CGisItemTrk::trkpt_t *pt)
+void CDetailsTrk::setMouseClickFocus(const CTrackData::trkpt_t *pt)
 {
     if(nullptr != pt)
     {
@@ -599,7 +576,7 @@ void CDetailsTrk::slotChangeReadOnlyMode(bool on)
 {
     trk.setReadOnlyMode(on);
     // as setReadOnlyMode() is a method of IGisItem it will bypass updateHistory() of the track
-    // Therefore we have to call updateVisuals() explicitely.
+    // Therefore we have to call updateVisuals() explicitly.
     trk.updateVisuals(CGisItemTrk::eVisualProject, "CDetailsTrk::slotChangeReadOnlyMode()");
     updateData();
 }
@@ -642,28 +619,20 @@ void CDetailsTrk::slotLinkActivated(const QUrl& url)
     }
 }
 
-void CDetailsTrk::slotActivitySelected(bool checked)
+void CDetailsTrk::slotSetActivities()
 {
-    if(!checked)
+    quint32 flags = CActivityTrk::selectActivity(this);
+    if(0 != flags)
     {
-        if(QMessageBox::warning(this, tr("Reset activities..."), tr("This will remove all activities from the track. Proceed?"), QMessageBox::Ok|QMessageBox::No, QMessageBox::Ok) != QMessageBox::Ok)
-        {
-            updateData();
-        }
-        else
-        {
-            trk.setActivity(CGisItemTrk::trkpt_t::eActNone, tr("None"), "://icons/48x48/ActNone.png");
-        }
+        trk.setActivity(flags);
     }
-    else
+}
+
+void CDetailsTrk::slotRemoveActivities()
+{
+    if(QMessageBox::warning(this, tr("Reset activities..."), tr("This will remove all activities from the track. Proceed?"), QMessageBox::Ok|QMessageBox::No, QMessageBox::Ok) == QMessageBox::Ok)
     {
-        QObject *s = sender();
-        bool ok = false;
-        quint32 flag = s->property("flag").toUInt(&ok);
-        if(ok)
-        {
-            trk.setActivity(flag, s->property("name").toString(), s->property("symbol").toString());
-        }
+        trk.setActivity(CTrackData::trkpt_t::eActNone);
     }
 }
 
