@@ -31,7 +31,7 @@ CScrOptTrk::CScrOptTrk(CGisItemTrk * trk, const QPoint& point, IMouse *parent)
     setupUi(this);
     setOrigin(point);
     label->setFont(CMainWindow::self().getMapFont());
-    label->setText(trk->getInfo());
+    label->setText(trk->getInfo(true, false));
     adjustSize();
 
     toolProfile->setChecked(trk->hasUserFocus());
@@ -41,6 +41,7 @@ CScrOptTrk::CScrOptTrk(CGisItemTrk * trk, const QPoint& point, IMouse *parent)
     toolEdit->setDisabled(isOnDevice);
     toolReverse->setDisabled(isOnDevice);
     toolRange->setDisabled(isOnDevice);
+    toolCopyWithWpt->setEnabled(trk->getNumberOfAttachedWpt() != 0);
 
     IGisProject * project = trk->getParentProject();
     if(project != nullptr)
@@ -76,6 +77,7 @@ CScrOptTrk::CScrOptTrk(CGisItemTrk * trk, const QPoint& point, IMouse *parent)
     connect(toolReverse,     &QToolButton::clicked, this, &CScrOptTrk::slotReverse);
     connect(toolCombine,     &QToolButton::clicked, this, &CScrOptTrk::slotCombine);
     connect(toolRange,       &QToolButton::clicked, this, &CScrOptTrk::slotRange);
+    connect(toolCopyWithWpt, &QToolButton::clicked, this, &CScrOptTrk::slotCopyWithWpt);
 
 
     // reset user focus if the track has it
@@ -141,6 +143,12 @@ void CScrOptTrk::slotRange()
     deleteLater();
 }
 
+void CScrOptTrk::slotCopyWithWpt()
+{
+    CGisWidget::self().copyTrkWithWptByKey(key);
+    deleteLater();
+}
+
 void CScrOptTrk::draw(QPainter& p)
 {
     IGisItem * item = CGisWidget::self().getItemByKey(key);
