@@ -237,9 +237,14 @@ bool CGisItemWpt::getNewWptData(QPointF& pt, QString& icon, QString& name)
     return true;
 }
 
-QString CGisItemWpt::getInfo(bool allowEdit) const
+QString CGisItemWpt::getInfo(bool showName, bool showFullText) const
 {
-    QString str = "<div style='font-weight: bold;'>" + getName() + "</div>";
+    QString str = "<div>";
+
+    if(showName)
+    {
+        str = "<b>" + getName() + "</b><br/>\n";
+    }
 
     if(geocache.hasData)
     {
@@ -286,36 +291,34 @@ QString CGisItemWpt::getInfo(bool allowEdit) const
             str += "<br/>\n";
         }
 
-        if(desc.count() < 200)
+        if(showFullText || (desc.count() < 300))
         {
             str += desc;
         }
         else
         {
-            str += desc.left(197) + "...";
+            str += desc.left(297) + "...";
         }
     }
-    else
-    {
-        QString cmt = removeHtml(wpt.cmt).simplified();
-        if(cmt.count())
-        {
-            if(!str.isEmpty())
-            {
-                str += "<br/>\n";
-            }
 
-            if(cmt.count() < 200)
-            {
-                str += cmt;
-            }
-            else
-            {
-                str += cmt.left(197) + "...";
-            }
+    QString cmt = removeHtml(wpt.cmt).simplified();
+    if((cmt != desc) && cmt.count())
+    {
+        if(!str.isEmpty())
+        {
+            str += "<br/>\n";
+        }
+
+        if(showFullText || cmt.count() < 300)
+        {
+            str += cmt;
+        }
+        else
+        {
+            str += cmt.left(297) + "...";
         }
     }
-    return str;
+    return str + "</div>";
 }
 
 IScrOpt * CGisItemWpt::getScreenOptions(const QPoint& origin, IMouse * mouse)
@@ -494,7 +497,7 @@ void CGisItemWpt::drawItem(QPainter& p, const QRectF& viewport, CGisDraw * gis)
     if(mouseIsOverBubble && !doBubbleMove && !doBubbleSize && rectBubble.isValid() && !isReadOnly())
     {
         QPainterPath clip;
-        clip.addRoundedRect(rectBubble, 5, 5);
+        clip.addRoundedRect(rectBubble, RECT_RADIUS, RECT_RADIUS);
         p.setClipPath(clip);
 
         QRect barTop(rectBubble.topLeft(), QSize(rectBubble.width(), 26));
@@ -509,9 +512,9 @@ void CGisItemWpt::drawItem(QPainter& p, const QRectF& viewport, CGisDraw * gis)
         p.drawRect(barBottom);
 
         p.setBrush(Qt::white);
-        p.drawRoundedRect(rectBubbleMove.adjusted(-2,-2,2,2), 3,3);
-        p.drawRoundedRect(rectBubbleEdit.adjusted(-2,-2,2,2), 3,3);
-        p.drawRoundedRect(rectBubbleSize.adjusted(-2,-2,2,2), 3,3);
+        p.drawRoundedRect(rectBubbleMove.adjusted(-2,-2,2,2), RECT_RADIUS, RECT_RADIUS);
+        p.drawRoundedRect(rectBubbleEdit.adjusted(-2,-2,2,2), RECT_RADIUS, RECT_RADIUS);
+        p.drawRoundedRect(rectBubbleSize.adjusted(-2,-2,2,2), RECT_RADIUS, RECT_RADIUS);
 
         p.drawPixmap(rectBubbleMove, QPixmap("://icons/32x32/MoveArrow.png"));
         p.drawPixmap(rectBubbleEdit, QPixmap("://icons/32x32/EditDetails.png"));
@@ -653,7 +656,7 @@ QPolygonF CGisItemWpt::makePolyline(const QPointF& anchor, const QRectF& r)
         }
 
         QPainterPath path1;
-        path1.addRoundedRect(r,5,5);
+        path1.addRoundedRect(r, RECT_RADIUS, RECT_RADIUS);
         QPainterPath path2;
         path2.addPolygon(poly2);
 
