@@ -150,7 +150,7 @@ public:
        @brief Save waypoint to GPX tree
        @param gpx   The <gpx> node to append by the waypoint
      */
-    void save(QDomNode& gpx) override;
+    void save(QDomNode& gpx, bool strictGpx11) override;
     /**
        @brief Save waypoint to TwoNav waypoint file
        @param out   the text stream to write to
@@ -219,7 +219,7 @@ public:
         return wpt.name.isEmpty() ? noName : wpt.name;
     }
 
-    QString getInfo(bool allowEdit = false) const override;
+    QString getInfo(bool showName, bool showFullText) const override;
     QPointF getPosition() const
     {
         return QPointF(wpt.lon, wpt.lat);
@@ -262,6 +262,12 @@ public:
         return images;
     }
 
+    QDateTime getTimestamp() const override
+    {
+        return wpt.time;
+    }
+
+
     IScrOpt* getScreenOptions(const QPoint &origin, IMouse * mouse) override;
 
     QPointF getPointCloseBy(const QPoint& ) override
