@@ -16,6 +16,7 @@
 
 **********************************************************************************************/
 
+#include "helpers/Signals.h"
 #include "map/CMapDraw.h"
 #include "map/CMapPropSetup.h"
 #include "map/IMap.h"
@@ -31,39 +32,24 @@ CMapPropSetup::CMapPropSetup(IMap * mapfile, CMapDraw *map)
 
     slotPropertiesChanged();
 
-    connect(sliderOpacity, SIGNAL(valueChanged(int)), mapfile, SLOT(slotSetOpacity(int)));
-    connect(sliderOpacity, SIGNAL(valueChanged(int)), map, SLOT(emitSigCanvasUpdate()));
-    connect(map, SIGNAL(sigScaleChanged(QPointF)), this, SLOT(slotScaleChanged(QPointF)));
-    connect(toolSetMinScale, SIGNAL(toggled(bool)), this, SLOT(slotSetMinScale(bool)));
-    connect(toolSetMaxScale, SIGNAL(toggled(bool)), this, SLOT(slotSetMaxScale(bool)));
+    connect(sliderOpacity,       &QSlider::valueChanged,     mapfile, &IMap::slotSetOpacity);
+    connect(sliderOpacity,       &QSlider::valueChanged,     map,     &CMapDraw::emitSigCanvasUpdate);
+    connect(map,                 &CMapDraw::sigScaleChanged, this,    &CMapPropSetup::slotScaleChanged);
+    connect(toolSetMinScale,     &QToolButton::toggled,      this,    &CMapPropSetup::slotSetMinScale);
+    connect(toolSetMaxScale,     &QToolButton::toggled,      this,    &CMapPropSetup::slotSetMaxScale);
 
-    connect(checkPolygons, SIGNAL(toggled(bool)), mapfile, SLOT(slotSetShowPolygons(bool)));
-    connect(checkPolylines, SIGNAL(toggled(bool)), mapfile, SLOT(slotSetShowPolylines(bool)));
-    connect(checkPoints, SIGNAL(toggled(bool)), mapfile, SLOT(slotSetShowPOIs(bool)));
-    connect(checkPolygons, SIGNAL(clicked()), map, SLOT(emitSigCanvasUpdate()));
-    connect(checkPolylines, SIGNAL(clicked()), map, SLOT(emitSigCanvasUpdate()));
-    connect(checkPoints, SIGNAL(clicked()), map, SLOT(emitSigCanvasUpdate()));
+    connect(checkPolygons,       &QCheckBox::toggled,        mapfile, &IMap::slotSetShowPolygons);
+    connect(checkPolylines,      &QCheckBox::toggled,        mapfile, &IMap::slotSetShowPolylines);
+    connect(checkPoints,         &QCheckBox::toggled,        mapfile, &IMap::slotSetShowPOIs);
+    connect(checkPolygons,       &QCheckBox::clicked,        map,     &CMapDraw::emitSigCanvasUpdate);
+    connect(checkPolylines,      &QCheckBox::clicked,        map,     &CMapDraw::emitSigCanvasUpdate);
+    connect(checkPoints,         &QCheckBox::clicked,        map,     &CMapDraw::emitSigCanvasUpdate);
 
-    connect(spinCacheSize, SIGNAL(valueChanged(int)), mapfile, SLOT(slotSetCacheSize(qint32)));
-    connect(spinCacheExpiration, SIGNAL(valueChanged(int)), mapfile, SLOT(slotSetCacheExpiration(qint32)));
+    connect(spinCacheSize,       static_cast<void (QSpinBox::*)(int) >(&QSpinBox::valueChanged), mapfile, &IMap::slotSetCacheSize);
+    connect(spinCacheExpiration, static_cast<void (QSpinBox::*)(int) >(&QSpinBox::valueChanged), mapfile, &IMap::slotSetCacheExpiration);
 
-    if(mapfile->hasFeatureVectorItems())
-    {
-        frameVectorItems->show();
-    }
-    else
-    {
-        frameVectorItems->hide();
-    }
-
-    if(mapfile->hasFeatureTileCache())
-    {
-        frameTileCache->show();
-    }
-    else
-    {
-        frameTileCache->hide();
-    }
+    frameVectorItems->setVisible( mapfile->hasFeatureVectorItems() );
+    frameTileCache->setVisible( mapfile->hasFeatureTileCache() );
 
     if(mapfile->hasFeatureLayers())
     {
@@ -80,23 +66,16 @@ CMapPropSetup::~CMapPropSetup()
 {
 }
 
-void CMapPropSetup::resizeEvent(QResizeEvent * e)
+void CMapPropSetup::resizeEvent(QResizeEvent * e) /* override */
 {
     IMapProp::resizeEvent(e);
     updateScaleLabel();
 }
 
-void CMapPropSetup::slotPropertiesChanged()
+void CMapPropSetup::slotPropertiesChanged() /* override */
 {
+    X______________BlockAllSignals______________X(this);
     // block all signals to avoid retrigger
-    sliderOpacity->blockSignals(true);
-    toolSetMaxScale->blockSignals(true);
-    toolSetMinScale->blockSignals(true);
-    checkPolygons->blockSignals(true);
-    checkPolylines->blockSignals(true);
-    checkPoints->blockSignals(true);
-    spinCacheSize->blockSignals(true);
-    spinCacheExpiration->blockSignals(true);
 
     // opacity and visibility settings
     sliderOpacity->setValue(mapfile->getOpacity());
@@ -119,14 +98,7 @@ void CMapPropSetup::slotPropertiesChanged()
     spinCacheExpiration->setValue(mapfile->getCacheExpiration());
 
     // unblock all signals
-    sliderOpacity->blockSignals(false);
-    toolSetMaxScale->blockSignals(false);
-    toolSetMinScale->blockSignals(false);
-    checkPolygons->blockSignals(false);
-    checkPolylines->blockSignals(false);
-    checkPoints->blockSignals(false);
-    spinCacheSize->blockSignals(false);
-    spinCacheExpiration->blockSignals(false);
+    X_____________UnBlockAllSignals_____________X(this);
 }
 
 void CMapPropSetup::slotScaleChanged(const QPointF& s)
