@@ -159,13 +159,13 @@ CMapTMS::CMapTMS(const QString &filename, CMapDraw *parent)
 
     // create default cache path from filename
     QFileInfo fi(filename);
-    slotSetCachePath(QDir(CMapDraw::getCacheRoot()).absoluteFilePath(fi.baseName()));
+    slotSetCachePath(QDir(CMapDraw::getCacheRoot()).absoluteFilePath(fi.completeBaseName()));
 
     accessManager = new QNetworkAccessManager(parent->thread());
     connect(this,          &CMapTMS::sigQueueChanged,        this, &CMapTMS::slotQueueChanged);
     connect(accessManager, &QNetworkAccessManager::finished, this, &CMapTMS::slotRequestFinished);
 
-    name = fi.baseName().replace("_", " ");
+    name = fi.completeBaseName().replace("_", " ");
 
     isActivated = true;
 }
