@@ -36,9 +36,9 @@ public:
     IMap(quint32 features, CMapDraw * parent);
     virtual ~IMap();
 
-    void saveConfig(QSettings& cfg);
+    void saveConfig(QSettings& cfg) override;
 
-    void loadConfig(QSettings& cfg);
+    void loadConfig(QSettings& cfg) override;
 
     enum features_e
     {
@@ -54,7 +54,7 @@ public:
        @brief Test if map has been loaded successfully
        @return Return false if map is not loaded
      */
-    bool activated()
+    bool activated() const
     {
         return isActivated;
     }
@@ -69,79 +69,62 @@ public:
      */
     virtual IMapProp *getSetup();
 
-    /**
-       @brief getInfo
-       @param px
-       @param str
-     */
-    virtual void getInfo(const QPoint& px, QString& str)
-    {
-        Q_UNUSED(px);
-        Q_UNUSED(str);
-    }
-    /**
-       @brief getToolTip
-       @param px
-       @param str
-     */
-    virtual void getToolTip(const QPoint& px, QString& str)
-    {
-        Q_UNUSED(px);
-        Q_UNUSED(str);
-    }
+    virtual void getInfo(const QPoint&, QString&) {}
+
+    virtual void getToolTip(const QPoint&, QString&) {}
 
     /**
        @brief Return copyright notice if any
        @return If no copyright notice has been decoded the string will be empty
      */
-    const QString& getCopyright()
+    const QString& getCopyright() const
     {
         return copyright;
     }
 
-    bool hasFeatureVisibility()
+    bool hasFeatureVisibility() const
     {
         return flagsFeature & eFeatVisibility;
     }
-    bool hasFeatureVectorItems()
+    bool hasFeatureVectorItems() const
     {
         return flagsFeature & eFeatVectorItems;
     }
-    bool hasFeatureTileCache()
+    bool hasFeatureTileCache() const
     {
         return flagsFeature & eFeatTileCache;
     }
-    bool hasFeatureLayers()
+    bool hasFeatureLayers() const
     {
         return flagsFeature & eFeatLayers;
     }
 
-    bool getShowPolygons()
+    bool getShowPolygons() const
     {
         return showPolygons;
     }
 
-    bool getShowPolylines()
+    bool getShowPolylines() const
     {
         return showPolylines;
     }
 
-    bool getShowPOIs()
+    bool getShowPOIs() const
     {
         return showPOIs;
     }
 
-    const QString& getCachePath()
+    const QString& getCachePath() const
     {
         return cachePath;
     }
 
-    qint32 getCacheSize()
+    qint32 getCacheSize() const
     {
         return cacheSizeMB;
     }
 
-    qint32 getCacheExpiration()
+    qint32 getCacheExpiration() const
     {
         return cacheExpiration;
     }
@@ -193,8 +176,8 @@ public slots:
 
 
 protected:
-    void convertRad2M(QPointF &p);
-    void convertM2Rad(QPointF &p);
+    void convertRad2M(QPointF &p) const;
+    void convertM2Rad(QPointF &p) const;
 
 
     /**
@@ -203,22 +186,23 @@ protected:
        @param l     a 4 point polygon to fit the tile in
        @param p     the QPainter used to paint the tile
      */
-    void drawTile(QImage& img, QPolygonF& l, QPainter& p);
+    void drawTile(const QImage& img, QPolygonF& l, QPainter& p);
 
     /// the drawcontext this map belongs to
     CMapDraw * map;
 
-    /// source projection of the current map file
     /**
+        Source projection of the current map file
         Has to be set by subclass. Destruction has to be
         handled by subclass.
      */
-    projPJ pjsrc = 0;
-    /// target projection
+    projPJ pjsrc = nullptr;
+
     /**
+        target projection
         Is set by IMap() to WGS84. Will be freed by ~IMap()
      */
-    projPJ pjtar = 0;
+    projPJ pjtar = nullptr;
 
     /**
        @brief True if map was loaded successfully
@@ -231,22 +215,15 @@ protected:
     /// flag field for features defined in features_e
     quint32 flagsFeature;
 
-    /// vector maps only: hide/show polygons
-    bool showPolygons = true;
-    /// vector maps only: hide/show polylines
-    bool showPolylines = true;
-    /// vector maps only: hide/show point of interest
-    bool showPOIs = true;
+    bool showPolygons  = true; //< vector maps only: hide/show polygons
+    bool showPolylines = true; //< vector maps only: hide/show polylines
+    bool showPOIs      = true; //< vector maps only: hide/show point of interest
 
-    /// streaming map only: path to cached tiles
-    QString cachePath;
-    /// streaming map only: maximum size of all tiles in cache [MByte]
-    qint32 cacheSizeMB = 100;
-    /// streaming map only: maximum age of tiles in cache [days]
-    qint32 cacheExpiration = 8;
+    QString cachePath;            //< streaming map only: path to cached tiles
+    qint32 cacheSizeMB     = 100; //< streaming map only: maximum size of all tiles in cache [MByte]
+    qint32 cacheExpiration =   8; //< streaming map only: maximum age of tiles in cache [days]
 
-    /// a copyright string to be displayed as tool tip
-    QString copyright;
+    QString copyright; //< a copyright string to be displayed as tool tip
 };
 
 
