@@ -34,14 +34,14 @@ public:
     CMouseMoveWpt(CGisItemWpt& wpt, CGisDraw * gis, CCanvas * parent);
     virtual ~CMouseMoveWpt();
 
-    void draw(QPainter& p,  CCanvas::redraw_e needsRedraw, const QRect &rect);
-    void mousePressEvent(QMouseEvent * e);
-    void mouseMoveEvent(QMouseEvent * e);
-    void mouseReleaseEvent(QMouseEvent *e);
-    void wheelEvent(QWheelEvent * e);
+    void draw(QPainter& p,  CCanvas::redraw_e needsRedraw, const QRect &rect) override;
+    void mousePressEvent(QMouseEvent *e) override;
+    void mouseMoveEvent(QMouseEvent *e) override;
+    void mouseReleaseEvent(QMouseEvent *e) override;
+    void wheelEvent(QWheelEvent *e) override;
 
 protected slots:
-    virtual void slotPanCanvas();
+    void slotPanCanvas() override;
 
 private:
     IGisItem::key_t key;
