@@ -35,16 +35,7 @@ CMouseRangeTrk::CMouseRangeTrk(CGisItemTrk &trk, CGisDraw *gis, CCanvas *parent)
     // switch to full mode to show deleted (hidden) track points, too
     trk.setMode(CGisItemTrk::eModeRange, "CMouseRangeTrk");
 
-    // reset user focus if the track has it
-    trk.setMouseFocusByPoint(NOPOINT, CGisItemTrk::eFocusMouseMove, "CMouseRangeTrk");
-    trk.setMouseFocusByPoint(NOPOINT, CGisItemTrk::eFocusMouseClick, "CMouseRangeTrk");
-
-    canvas->reportStatus(key.item, tr("<b>Select Range</b><br/>Select first track point. And then a second one.<br/>"));
-    /*
-        trigger complete update of GIS components to make sure all changes to
-        the originating object are reflected on the canvas
-     */
-    canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
+    resetState();
 }
 
 CMouseRangeTrk::~CMouseRangeTrk()
@@ -87,7 +78,7 @@ void CMouseRangeTrk::draw(QPainter& p,  CCanvas::redraw_e, const QRect &)
 void CMouseRangeTrk::mousePressEvent(QMouseEvent * e)
 {
     canvas->reportStatus(key.item, "");
-    point  = e->pos();
+    point = e->pos();
     if(e->button() == Qt::RightButton)
     {
         canvas->resetMouse();
@@ -122,7 +113,7 @@ void CMouseRangeTrk::mousePressEvent(QMouseEvent * e)
                 scrOptRange = new CScrOptRangeTrk(pt, trk, this);
                 connect(scrOptRange->toolHidePoints, &QToolButton::clicked, this, &CMouseRangeTrk::slotHidePoints);
                 connect(scrOptRange->toolShowPoints, &QToolButton::clicked, this, &CMouseRangeTrk::slotShowPoints);
-                connect(scrOptRange->toolActivity,   &QToolButton::clicked, this, &CMouseRangeTrk::slotActivity);
+                connect(scrOptRange.data(), &CScrOptRangeTrk::activitySelected, this, &CMouseRangeTrk::slotActivity);
                 connect(scrOptRange->toolCopy,       &QToolButton::clicked, this, &CMouseRangeTrk::slotCopy);
 
                 state = eStateRangeSelected;
@@ -146,7 +137,7 @@ void CMouseRangeTrk::mousePressEvent(QMouseEvent * e)
 
 void CMouseRangeTrk::mouseMoveEvent(QMouseEvent * e)
 {
-    point  = e->pos();
+    point = e->pos();
 
     switch(state)
     {
@@ -230,9 +221,11 @@ void CMouseRangeTrk::resetState()
     {
         scrOptRange->deleteLater();
     }
-    state   = eStateIdle;
-    anchor  = NOPOINTF;
-    canvas->update();
+    state  = eStateIdle;
+    anchor = NOPOINTF;
+
+    canvas->reportStatus(key.item, tr("<b>Select Range</b><br/>Select first track point with left mouse button. And then a second one. Leave range selection with a click of the right mouse button.<br/>"));
+    canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
 }
 
 void CMouseRangeTrk::slotHidePoints()
@@ -246,8 +239,7 @@ void CMouseRangeTrk::slotHidePoints()
         canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
     }
 
-    scrOptRange->deleteLater();
-    canvas->resetMouse();
+    resetState();
 }
 
 void CMouseRangeTrk::slotShowPoints()
@@ -261,18 +253,17 @@ void CMouseRangeTrk::slotShowPoints()
         canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
     }
 
-    scrOptRange->deleteLater();
-    canvas->resetMouse();
+    resetState();
 }
 
-void CMouseRangeTrk::slotActivity()
+void CMouseRangeTrk::slotActivity(quint32 flags)
 {
     QMutexLocker lock(&IGisItem::mutexItems);
 
     CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(CGisWidget::self().getItemByKey(key));
-    if(trk != nullptr)
+    if(nullptr != trk)
     {
-        trk->setActivity();
+        trk->setActivityRange(flags);
         canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
     }
 
