@@ -45,7 +45,7 @@ public:
 private slots:
     void slotHidePoints();
     void slotShowPoints();
-    void slotActivity();
+    void slotActivity(quint32 flags);
     void slotCopy();
 
 private:
