@@ -31,8 +31,11 @@ CScrOptRangeTrk::CScrOptRangeTrk(const QPointF &point, CGisItemTrk * trk, IMouse
         setParent(parent);
     }
     setupUi(this);
+
+    bool noRange = !trk->isRangeSelected();
+
     label->setFont(CMainWindow::self().getMapFont());
-    label->setText(trk->getInfoRange());
+    label->setText(noRange ?  tr("No range selected") : trk->getInfoRange());
     adjustSize();
 
     setOrigin(point.toPoint());
@@ -40,10 +43,14 @@ CScrOptRangeTrk::CScrOptRangeTrk(const QPointF &point, CGisItemTrk * trk, IMouse
     move(point.toPoint() + QPoint(-width()/2,SCR_OPT_OFFSET));
     show();
 
+    toolCopy->setDisabled(noRange);
+    toolActivity->setDisabled(noRange);
+
     connect(toolHidePoints, &QToolButton::clicked, this, &CScrOptRangeTrk::hide);
     connect(toolShowPoints, &QToolButton::clicked, this, &CScrOptRangeTrk::hide);
-    connect(toolActivity,   &QToolButton::clicked, this, &CScrOptRangeTrk::hide);
     connect(toolCopy,       &QToolButton::clicked, this, &CScrOptRangeTrk::hide);
+
+    connect(toolActivity,   &QToolButton::clicked, this, &CScrOptRangeTrk::selectActivity);
 }
 
 CScrOptRangeTrk::~CScrOptRangeTrk()
@@ -58,3 +65,13 @@ void CScrOptRangeTrk::draw(QPainter& p)
     }
 }
 
+void CScrOptRangeTrk::selectActivity()
+{
+    quint32 flags = CActivityTrk::selectActivity(this);
+    if(0 != flags)
+    {
+        emit activitySelected(flags);
+    }
+
+    hide();
+}
