@@ -19,7 +19,7 @@
 #ifndef IMOUSE_H
 #define IMOUSE_H
 
-#include <canvas/CCanvas.h>
+#include "canvas/CCanvas.h"
 
 #include <QCursor>
 #include <QObject>
@@ -27,11 +27,9 @@
 
 class QMouseEvent;
 class QWheelEvent;
-class CCanvas;
 class QTimer;
 class CGisDraw;
 
-
 class IMouse : public QObject
 {
     Q_OBJECT
@@ -39,20 +37,15 @@ public:
     IMouse(CGisDraw * gis, CCanvas * canvas);
     virtual ~IMouse();
 
-    enum type_e
-    {
-        eNormal
-    };
-
     virtual void draw(QPainter& p, CCanvas::redraw_e needsRedraw, const QRect &rect) = 0;
-    virtual void mousePressEvent(QMouseEvent * e) = 0;
-    virtual void mouseMoveEvent(QMouseEvent * e) = 0;
+    virtual void mousePressEvent(QMouseEvent *e) = 0;
+    virtual void mouseMoveEvent(QMouseEvent *e) = 0;
     virtual void mouseReleaseEvent(QMouseEvent *e) = 0;
     virtual void mouseDoubleClickEvent(QMouseEvent *e)
     {
     }
-    virtual void wheelEvent(QWheelEvent * e) = 0;
-    virtual void keyPressEvent(QKeyEvent * e)
+    virtual void wheelEvent(QWheelEvent *e) = 0;
+    virtual void keyPressEvent(QKeyEvent *e)
     {
     }
 
@@ -61,12 +54,12 @@ public:
         Each mouse function is represented by a special cursor. The main
         widget uses this method to query the current cursor.
      */
-    operator const QCursor&()
+    operator const QCursor&() const
     {
         return cursor;
     }
 
-    CCanvas * getCanvas()
+    CCanvas * getCanvas() const
     {
         return canvas;
     }
