@@ -114,17 +114,15 @@ void ILineOp::mousePressEvent(QMouseEvent * e)
     {
         mousePressEventEx(e);
     }
-    else
-    {
-        const QPoint& pos = e->pos();
 
-        if(e->button() == Qt::LeftButton)
-        {
-            lastPos    = pos;
-            mapMove    = true;
-            mapDidMove = false;
-        }
+
+    if(e->button() == Qt::LeftButton)
+    {
+        lastPos    = e->pos();
+        mapMove    = true;
+        mapDidMove = false;
     }
+
     showRoutingErrorMessage(QString());
 }
 
@@ -132,27 +130,26 @@ void ILineOp::mouseMoveEvent(QMouseEvent * e)
 {
     const QPoint& pos = e->pos();
 
-    if(mapMove)
+    if(mapMove && (pos != lastPos))
     {
-        if(pos != lastPos)
-        {
-            QPoint delta = pos - lastPos;
-            canvas->moveMap(delta);
-            mapDidMove  = true;
-        }
-    }
-    else
-    {
-        updateLeadLines(idxFocus);
-        mouseMoveEventEx(e);
+        QPoint delta = pos - lastPos;
+        canvas->moveMap(delta);
+        mapDidMove  = true;
     }
 
+    updateLeadLines(idxFocus);
+    mouseMoveEventEx(e);
+
     lastPos = pos;
 }
 
 void ILineOp::mouseReleaseEvent(QMouseEvent *e)
 {
-    mouseReleaseEventEx(e);
+    if(!mapDidMove)
+    {
+        mouseReleaseEventEx(e);
+    }
+
     mapMove     = false;
     mapDidMove  = false;
 }
