@@ -38,7 +38,7 @@ public:
 
     void updateData() override;
 
-    void setMouseFocus(const CGisItemTrk::trkpt_t * ptMouseMove) override;
+    void setMouseFocus(const CTrackData::trkpt_t * ptMouseMove) override;
 
 public slots:
     void setLimits();
