@@ -266,7 +266,6 @@ void IPlot::draw(QPainter& p)
     }
 
     p.drawImage(0,0,buffer);
-
     drawDecoration(p);
 }
 
@@ -316,7 +315,25 @@ void IPlot::mouseMoveEvent(QMouseEvent * e)
         return;
     }
 
-    QPoint pos  = e->pos();
+    QPoint pos      = e->pos();
+    mouseDidMove    = (e->buttons() == Qt::LeftButton);
+    if(mouseDidMove)
+    {
+        if(!scrOptRange.isNull())
+        {
+            delete scrOptRange;
+        }
+        QPoint diff = pos - posLast;
+
+        data->x().move(-diff.x());
+        data->y().move( diff.y());
+        needsRedraw = true;
+        update();
+
+        posLast = pos;
+        return;
+    }
+
     posMouse1    = NOPOINT;
     if(graphAreaContainsMousePos(pos))
     {
@@ -357,31 +374,30 @@ void IPlot::setMouseFocus(qreal pos, enum CGisItemTrk::focusmode_e fm)
 
 void IPlot::mousePressEvent(QMouseEvent * e)
 {
-    if(data->lines.isEmpty() || data->badData || !data->x().isValid() || !data->y().isValid())
+    if((e->button() == Qt::LeftButton) && (mode == eModeIcon))
     {
-        // [Issue #106 ] Profil with no or bad data does not open trackdetails
-        //
-        // even if there is no data at least open the track edit dialog
-        if((e->button() == Qt::LeftButton) && (mode == eModeIcon))
-        {
-            trk->edit();
-        }
-
-        return;
+        trk->edit();
     }
 
-    bool wasProcessed = true;
+    mouseDidMove    = false;
+    posLast         = e->pos();
+}
 
-    QPoint pos = e->pos();
-    posMouse1  = graphAreaContainsMousePos(pos) ? pos : NOPOINT;
+void IPlot::mouseReleaseEvent(QMouseEvent * e)
+{
     if(e->button() == Qt::LeftButton)
     {
-        if(mode == eModeIcon)
+        if((mode == eModeIcon) || mouseDidMove)
         {
-            trk->edit();
+            mouseDidMove = false;
+            return;
         }
         else
         {
+            QPoint pos = e->pos();
+            posMouse1  = graphAreaContainsMousePos(pos) ? pos : NOPOINT;
+
+            bool wasProcessed = true;
             // set point of focus at track object
             qreal x = data->x().pt2val(posMouse1.x() - left);
 
@@ -419,9 +435,10 @@ void IPlot::mousePressEvent(QMouseEvent * e)
                 scrOptRange = new CScrOptRangeTrk(pos, trk, &dummyMouse, this);
                 connect(scrOptRange->toolHidePoints, &QToolButton::clicked, this, &IPlot::slotHidePoints);
                 connect(scrOptRange->toolShowPoints, &QToolButton::clicked, this, &IPlot::slotShowPoints);
-                connect(scrOptRange->toolActivity,   &QToolButton::clicked, this, &IPlot::slotActivity);
                 connect(scrOptRange->toolCopy,       &QToolButton::clicked, this, &IPlot::slotCopy);
 
+                connect(scrOptRange.data(), &CScrOptRangeTrk::activitySelected, this, &IPlot::slotActivity);
+
                 /* Adjust position of screen option widget if the widget is out of the visible area*/
                 QRect r1 = scrOptRange->geometry();
                 QRect r2 = geometry();
@@ -486,10 +503,42 @@ void IPlot::wheelEvent(QWheelEvent * e)
 {
     bool in = CMainWindow::self().flipMouseWheel() ? (e->delta() < 0) : (e->delta() > 0);
 
-    data->x().zoom(in, e->pos().x() - left);
-    setSizes();
-    data->x().setScale(rectGraphArea.width());
+    bool doHorizontalZoom   = false;
+    bool doVerticalZoom     = false;
 
+    switch(QApplication::keyboardModifiers())
+    {
+    case Qt::AltModifier:
+        doHorizontalZoom    = true;
+        break;
+
+    case Qt::ControlModifier:
+        doVerticalZoom      = true;
+        break;
+
+    case Qt::NoModifier:
+        doHorizontalZoom    = true;
+        doVerticalZoom      = true;
+        break;
+    }
+
+    if(doHorizontalZoom)
+    {
+        data->x().zoom(in, e->pos().x() - left);
+        setSizes();
+        data->x().setScale(rectGraphArea.width());
+    }
+
+    if(doVerticalZoom)
+    {
+        data->y().zoom(in, e->pos().y() - bottom);
+        setSizes();
+        data->y().setScale(rectGraphArea.height());
+    }
+
+
+    QPoint p = mapToGlobal(e->pos() + QPoint(32,0));
+    QToolTip::showText(p,tr("Hold CTRL key for vertical zoom, only.\nHold ALT key for horizontal zoom, only."), this, QRect(), 500);
     needsRedraw = true;
     update();
 }
@@ -1070,7 +1119,7 @@ void IPlot::drawDecoration( QPainter &p )
 
                     p.setPen(Qt::NoPen);
                     p.setBrush(Qt::white);
-                    p.drawRoundedRect(r,3,3);
+                    p.drawRoundedRect(r, RECT_RADIUS, RECT_RADIUS);
 
                     p.setFont(f);
                     p.setPen(Qt::darkBlue);
@@ -1084,6 +1133,8 @@ void IPlot::drawDecoration( QPainter &p )
 
     if((idxSel1 != NOIDX) && (idxSel2 != NOIDX) && !data->badData)
     {
+        p.setClipRect(rectGraphArea);
+
         int penIdx = 3;
 
         const QPolygonF& polyline = data->lines.first().points.mid(idxSel1, idxSel2 - idxSel1 + 1);
@@ -1109,6 +1160,7 @@ void IPlot::drawDecoration( QPainter &p )
             p.drawLine(line.first().x(), top, line.first().x(), bottom);
             p.drawLine(line.last().x(),  top, line.last().x(),  bottom);
         }
+        p.setClipping(false);
     }
 
     if(!scrOptRange.isNull())
@@ -1203,7 +1255,7 @@ void IPlot::drawActivities(QPainter& p)
 
         rectIconFrame.moveCenter(QPoint(c,10));
         p.setBrush(QColor(255, 255, 255, 100));
-        p.drawRoundedRect(rectIconFrame, 3, 3);
+        p.drawRoundedRect(rectIconFrame, RECT_RADIUS, RECT_RADIUS);
 
         rectIcon.moveCenter(QPoint(c, 10));
         p.drawPixmap(rectIcon, QPixmap(range.icon));
@@ -1280,9 +1332,9 @@ void IPlot::slotShowPoints()
     slotStopRange();
 }
 
-void IPlot::slotActivity()
+void IPlot::slotActivity(quint32 flags)
 {
-    trk->setActivity();
+    trk->setActivityRange(flags);
     slotStopRange();
 }
 
@@ -1312,6 +1364,7 @@ void IPlot::slotStopRange()
 void IPlot::slotResetZoom()
 {
     data->x().resetZoom();
+    data->y().resetZoom();
     setSizes();
 
     needsRedraw = true;
@@ -1326,7 +1379,7 @@ void IPlot::slotAddWpt()
         return;
     }
 
-    const CGisItemTrk::trkpt_t * trkpt = trk->getMouseMoveFocusPoint();
+    const CTrackData::trkpt_t * trkpt = trk->getMouseMoveFocusPoint();
     if(trkpt == nullptr)
     {
         return;
@@ -1340,7 +1393,7 @@ void IPlot::slotAddWpt()
     }
 }
 
-void IPlot::setMouseRangeFocus(const CGisItemTrk::trkpt_t * ptRange1, const CGisItemTrk::trkpt_t *ptRange2)
+void IPlot::setMouseRangeFocus(const CTrackData::trkpt_t * ptRange1, const CTrackData::trkpt_t *ptRange2)
 {
     if(nullptr == ptRange1 || nullptr == ptRange2)
     {
@@ -1351,11 +1404,11 @@ void IPlot::setMouseRangeFocus(const CGisItemTrk::trkpt_t * ptRange1, const CGis
     {
         if(ptRange1->idxTotal < ptRange2->idxTotal)
         {
-            while(ptRange1->flags & CGisItemTrk::trkpt_t::eHidden)
+            while(ptRange1->isHidden())
             {
                 ptRange1++;
             }
-            while(ptRange2->flags & CGisItemTrk::trkpt_t::eHidden)
+            while(ptRange2->isHidden())
             {
                 ptRange2--;
             }
@@ -1364,11 +1417,11 @@ void IPlot::setMouseRangeFocus(const CGisItemTrk::trkpt_t * ptRange1, const CGis
         }
         else
         {
-            while(ptRange1->flags & CGisItemTrk::trkpt_t::eHidden)
+            while(ptRange1->isHidden())
             {
                 ptRange1--;
             }
-            while(ptRange2->flags & CGisItemTrk::trkpt_t::eHidden)
+            while(ptRange2->isHidden())
             {
                 ptRange2++;
             }
@@ -1381,8 +1434,12 @@ void IPlot::setMouseRangeFocus(const CGisItemTrk::trkpt_t * ptRange1, const CGis
 
 bool IPlot::isZoomed() const
 {
+    bool zoomed = false;
     qreal limMin, limMax, useMin, useMax;
     data->x().getLimits(limMin, limMax, useMin, useMax);
+    zoomed |= !((limMax - limMin) <= (useMax - useMin));
+    data->y().getLimits(limMin, limMax, useMin, useMax);
+    zoomed |= !((limMax - limMin) <= (useMax - useMin));
 
-    return !((limMax - limMin) <= (useMax - useMin));
+    return zoomed;
 }
