@@ -42,8 +42,8 @@ public:
     IPlot(CGisItemTrk * trk, CPlotData::axistype_e type, mode_e mode, QWidget * parent);
     virtual ~IPlot();
 
-    void setMouseRangeFocus(const CGisItemTrk::trkpt_t * ptRange1, const CGisItemTrk::trkpt_t * ptRange2) override;
-    void setMouseClickFocus(const CGisItemTrk::trkpt_t * pt) override {}
+    void setMouseRangeFocus(const CTrackData::trkpt_t * ptRange1, const CTrackData::trkpt_t * ptRange2) override;
+    void setMouseClickFocus(const CTrackData::trkpt_t * pt) override {}
 
     void save(QImage& image);
     void setSolid(bool yes)
@@ -65,7 +65,7 @@ private slots:
     void slotSave();
     void slotHidePoints();
     void slotShowPoints();
-    void slotActivity();
+    void slotActivity(quint32 flags);
     void slotCopy();
     void slotStopRange();
     void slotResetZoom();
@@ -81,14 +81,15 @@ protected:
     void setLimits();
     void resetZoom();
 
-    void paintEvent(QPaintEvent  *e) override;
+    void paintEvent(QPaintEvent *e) override;
     void resizeEvent(QResizeEvent *e) override;
-    void leaveEvent(QEvent       *e) override;
-    void enterEvent(QEvent       *e) override;
-    void keyPressEvent(QKeyEvent    *e) override;
-    void mouseMoveEvent(QMouseEvent  *e) override;
-    void mousePressEvent(QMouseEvent  *e) override;
-    void wheelEvent(QWheelEvent  *e) override;
+    void leaveEvent(QEvent *e) override;
+    void enterEvent(QEvent *e) override;
+    void keyPressEvent(QKeyEvent *e) override;
+    void mouseMoveEvent(QMouseEvent *e) override;
+    void mousePressEvent(QMouseEvent *e) override;
+    void mouseReleaseEvent(QMouseEvent * e) override;
+    void wheelEvent(QWheelEvent *e) override;
 
 
     void setSizes();
@@ -104,15 +105,15 @@ protected:
     void draw(QPainter& p);
     void draw();
     void drawData(QPainter& p);
-    void drawLabels( QPainter &p );
-    void drawXScale( QPainter &p );
-    void drawYScale( QPainter &p );
-    void drawGridX( QPainter &p );
-    void drawGridY( QPainter &p );
-    void drawXTic( QPainter &p );
-    void drawYTic( QPainter &p );
+    void drawLabels(QPainter &p);
+    void drawXScale(QPainter &p);
+    void drawYScale(QPainter &p);
+    void drawGridX(QPainter &p);
+    void drawGridY(QPainter &p);
+    void drawXTic(QPainter &p);
+    void drawYTic(QPainter &p);
     void drawLegend(QPainter& p);
-    void drawDecoration( QPainter &p );
+    void drawDecoration(QPainter &p);
     void drawTags(QPainter& p);
     void drawActivities(QPainter& p);
 
@@ -123,16 +124,20 @@ protected:
     // different draw modes
     mode_e mode;
     // buffer needs update
-    bool needsRedraw = true;
+    bool needsRedraw    = true;
 
-    bool showScale = true;
-    bool thinLine  = false;
-    bool solid     = false;
+    bool showScale      = true;
+    bool thinLine       = false;
+    bool solid          = false;
+
+    bool mouseDidMove   = false;
 
     QImage buffer;
     QPoint posMouse1 = NOPOINT; ///< pixel coordinate of mouse in graph area while in focus
     QPoint posMouse2 = NOPOINT; ///< pixel coordinate of mouse in graph area while in context menu function
 
+    QPoint posLast   = NOPOINT;
+
     /**
        @brief The track this plot is attached to
 
