@@ -16,8 +16,8 @@
 
 **********************************************************************************************/
 
-#include "helpers/CAppSetup.h"
 #include "helpers/CSettings.h"
+#include "setup/IAppSetup.h"
 
 #include "tool/CRoutinoDatabaseBuilder.h"
 
@@ -31,10 +31,10 @@ CRoutinoDatabaseBuilder::CRoutinoDatabaseBuilder(QWidget * parent)
 
     setObjectName(tr("Create Routino Database"));
 
-    connect(toolSourceFiles, SIGNAL(clicked()), this, SLOT(slotSelectSourceFiles()));
-    connect(toolTargetPath, SIGNAL(clicked()), this, SLOT(slotSelectTargetPath()));
-    connect(pushStart, SIGNAL(clicked()), this, SLOT(slotStart()));
-    connect(lineTargetPrefix, SIGNAL(textChanged(QString)), this, SLOT(enabelStartButton()));
+    connect(toolSourceFiles,  &QToolButton::clicked,   this, &CRoutinoDatabaseBuilder::slotSelectSourceFiles);
+    connect(toolTargetPath,   &QToolButton::clicked,   this, &CRoutinoDatabaseBuilder::slotSelectTargetPath);
+    connect(pushStart,        &QPushButton::clicked,   this, &CRoutinoDatabaseBuilder::slotStart);
+    connect(lineTargetPrefix, &QLineEdit::textChanged, this, &CRoutinoDatabaseBuilder::enabelStartButton);
 
     pushStart->setDisabled(true);
 
@@ -64,7 +64,7 @@ void CRoutinoDatabaseBuilder::slotSelectSourceFiles()
     cfg.setValue("RoutinoDatabaseBuilder/sourcePath", path);
 
     listWidget->clear();
-    foreach(const QString &file, files)
+    for(const QString &file : files)
     {
         new QListWidgetItem(QIcon("://icons/32x32/Map.png"), file, listWidget);
     }
@@ -118,7 +118,7 @@ void CRoutinoDatabaseBuilder::slotStart()
     pushStart->setDisabled(true);
 
     sourceFiles.clear();
-    foreach(const QListWidgetItem * item, listWidget->findItems("*", Qt::MatchWildcard))
+    for(const QListWidgetItem * item : listWidget->findItems("*", Qt::MatchWildcard))
     {
         sourceFiles << item->text();
     }
@@ -143,7 +143,7 @@ void CRoutinoDatabaseBuilder::finished(int exitCode, QProcess::ExitStatus status
         return;
     }
 
-    CAppSetup* instance = CAppSetup::getPlattformInstance();
+    IAppSetup* instance = IAppSetup::getPlatformInstance();
     if(sourceFiles.isEmpty())
     {
         QStringList args;
